"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2019-present BAIKAL AI Inc."""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DictType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DictTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DictType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TOKEN_INDEX: _DictType.ValueType  # 0
    """기본 배포사전에 사용되는 포맷
    전송시에는 쓰이지 않는다.
    """
    WORD_LIST: _DictType.ValueType  # 1
    """고유명사나 복합명사를 표기할 때 사용한다."""
    WORD_LIST_COMPOUND: _DictType.ValueType  # 2
    """# 전송시에만 사용하고 실제로는 쓰이지 추론시에는 쓰이지 않는다."""

class DictType(_DictType, metaclass=_DictTypeEnumTypeWrapper):
    """사전의 종류"""

TOKEN_INDEX: DictType.ValueType  # 0
"""기본 배포사전에 사용되는 포맷
전송시에는 쓰이지 않는다.
"""
WORD_LIST: DictType.ValueType  # 1
"""고유명사나 복합명사를 표기할 때 사용한다."""
WORD_LIST_COMPOUND: DictType.ValueType  # 2
"""# 전송시에만 사용하고 실제로는 쓰이지 추론시에는 쓰이지 않는다."""
global___DictType = DictType

class DictSet(google.protobuf.message.Message):
    """메모리 상에서 복합명사나 고유명사를 처리하기 위해서 쓰는 사전
    사전이 map으로 쓰이는 이유는 메모리 상에서 빠르게 사전 데이터의 존재여부를 점검하기
    위한 목적이다.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ItemsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]: ...
    type: global___DictType.ValueType
    name: builtins.str
    def __init__(
        self,
        *,
        items: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
        type: global___DictType.ValueType = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "name", b"name", "type", b"type"]) -> None: ...

global___DictSet = DictSet



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bareun import custom_dict_pb2 as bareun_dot_custom__dict__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CustomDictionaryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCustomDictionaryList = channel.unary_unary(
                '/bareun.CustomDictionaryService/GetCustomDictionaryList',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryListResponse.FromString,
                )
        self.GetCustomDictionary = channel.unary_unary(
                '/bareun.CustomDictionaryService/GetCustomDictionary',
                request_serializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryRequest.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryResponse.FromString,
                )
        self.UpdateCustomDictionary = channel.unary_unary(
                '/bareun.CustomDictionaryService/UpdateCustomDictionary',
                request_serializer=bareun_dot_custom__dict__pb2.UpdateCustomDictionaryRequest.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.UpdateCustomDictionaryResponse.FromString,
                )
        self.RemoveCustomDictionaries = channel.unary_unary(
                '/bareun.CustomDictionaryService/RemoveCustomDictionaries',
                request_serializer=bareun_dot_custom__dict__pb2.RemoveCustomDictionariesRequest.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.RemoveCustomDictionariesResponse.FromString,
                )
        self.CheckConflict = channel.unary_unary(
                '/bareun.CustomDictionaryService/CheckConflict',
                request_serializer=bareun_dot_custom__dict__pb2.CheckConflictRequest.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.CheckConflictResponse.FromString,
                )


class CustomDictionaryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCustomDictionaryList(self, request, context):
        """전체 목록을 다 가져오기
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomDictionary(self, request, context):
        """현재 저장되어 있는 사전 하나만 가져온다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCustomDictionary(self, request, context):
        """전체를 모두 다 바꿔치기하는 경우
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveCustomDictionaries(self, request, context):
        """여러 개를 한꺼번에 지운다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckConflict(self, request, context):
        """사용사 사전 사이의 충돌을 점검한다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CustomDictionaryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCustomDictionaryList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomDictionaryList,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryListResponse.SerializeToString,
            ),
            'GetCustomDictionary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomDictionary,
                    request_deserializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryRequest.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryResponse.SerializeToString,
            ),
            'UpdateCustomDictionary': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCustomDictionary,
                    request_deserializer=bareun_dot_custom__dict__pb2.UpdateCustomDictionaryRequest.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.UpdateCustomDictionaryResponse.SerializeToString,
            ),
            'RemoveCustomDictionaries': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveCustomDictionaries,
                    request_deserializer=bareun_dot_custom__dict__pb2.RemoveCustomDictionariesRequest.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.RemoveCustomDictionariesResponse.SerializeToString,
            ),
            'CheckConflict': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckConflict,
                    request_deserializer=bareun_dot_custom__dict__pb2.CheckConflictRequest.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.CheckConflictResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bareun.CustomDictionaryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CustomDictionaryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCustomDictionaryList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/GetCustomDictionaryList',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bareun_dot_custom__dict__pb2.GetCustomDictionaryListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCustomDictionary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/GetCustomDictionary',
            bareun_dot_custom__dict__pb2.GetCustomDictionaryRequest.SerializeToString,
            bareun_dot_custom__dict__pb2.GetCustomDictionaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCustomDictionary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/UpdateCustomDictionary',
            bareun_dot_custom__dict__pb2.UpdateCustomDictionaryRequest.SerializeToString,
            bareun_dot_custom__dict__pb2.UpdateCustomDictionaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveCustomDictionaries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/RemoveCustomDictionaries',
            bareun_dot_custom__dict__pb2.RemoveCustomDictionariesRequest.SerializeToString,
            bareun_dot_custom__dict__pb2.RemoveCustomDictionariesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckConflict(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/CheckConflict',
            bareun_dot_custom__dict__pb2.CheckConflictRequest.SerializeToString,
            bareun_dot_custom__dict__pb2.CheckConflictResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2019-present BAIKAL AI Inc."""
import abc
import bareun.language_service_pb2
import grpc

class LanguageServiceStub:
    """한국어에 대한 분석 서비스를 제공하는 서비스."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    AnalyzeSyntax: grpc.UnaryUnaryMultiCallable[
        bareun.language_service_pb2.AnalyzeSyntaxRequest,
        bareun.language_service_pb2.AnalyzeSyntaxResponse,
    ]
    """텍스트의 형태를 분석하고, 문장 경계를 파악하여 토큰 단위로 잘라낸다."""
    AnalyzeSyntaxList: grpc.UnaryUnaryMultiCallable[
        bareun.language_service_pb2.AnalyzeSyntaxListRequest,
        bareun.language_service_pb2.AnalyzeSyntaxListResponse,
    ]
    """복수의 문장을 대상으로 텍스트의 형태를 분석하고, 토큰 단위로 잘라낸다.
    복수의 문장에 대한 순서를 그대로 반환하고 문장을 분할하지 않는다.
    """
    Tokenize: grpc.UnaryUnaryMultiCallable[
        bareun.language_service_pb2.TokenizeRequest,
        bareun.language_service_pb2.TokenizeResponse,
    ]
    """한국어의 특성에 따라서 텍스트를 분절 단뤼로 구분해 낸다."""

class LanguageServiceServicer(metaclass=abc.ABCMeta):
    """한국어에 대한 분석 서비스를 제공하는 서비스."""

    @abc.abstractmethod
    def AnalyzeSyntax(
        self,
        request: bareun.language_service_pb2.AnalyzeSyntaxRequest,
        context: grpc.ServicerContext,
    ) -> bareun.language_service_pb2.AnalyzeSyntaxResponse:
        """텍스트의 형태를 분석하고, 문장 경계를 파악하여 토큰 단위로 잘라낸다."""
    @abc.abstractmethod
    def AnalyzeSyntaxList(
        self,
        request: bareun.language_service_pb2.AnalyzeSyntaxListRequest,
        context: grpc.ServicerContext,
    ) -> bareun.language_service_pb2.AnalyzeSyntaxListResponse:
        """복수의 문장을 대상으로 텍스트의 형태를 분석하고, 토큰 단위로 잘라낸다.
        복수의 문장에 대한 순서를 그대로 반환하고 문장을 분할하지 않는다.
        """
    @abc.abstractmethod
    def Tokenize(
        self,
        request: bareun.language_service_pb2.TokenizeRequest,
        context: grpc.ServicerContext,
    ) -> bareun.language_service_pb2.TokenizeResponse:
        """한국어의 특성에 따라서 텍스트를 분절 단뤼로 구분해 낸다."""

def add_LanguageServiceServicer_to_server(servicer: LanguageServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2019-present BAIKAL AI Inc."""
import abc
import bareun.custom_dict_pb2
import google.protobuf.empty_pb2
import grpc

class CustomDictionaryServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetCustomDictionaryList: grpc.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        bareun.custom_dict_pb2.GetCustomDictionaryListResponse,
    ]
    """전체 목록을 다 가져오기"""
    GetCustomDictionary: grpc.UnaryUnaryMultiCallable[
        bareun.custom_dict_pb2.GetCustomDictionaryRequest,
        bareun.custom_dict_pb2.GetCustomDictionaryResponse,
    ]
    """현재 저장되어 있는 사전 하나만 가져온다."""
    UpdateCustomDictionary: grpc.UnaryUnaryMultiCallable[
        bareun.custom_dict_pb2.UpdateCustomDictionaryRequest,
        bareun.custom_dict_pb2.UpdateCustomDictionaryResponse,
    ]
    """전체를 모두 다 바꿔치기하는 경우"""
    RemoveCustomDictionaries: grpc.UnaryUnaryMultiCallable[
        bareun.custom_dict_pb2.RemoveCustomDictionariesRequest,
        bareun.custom_dict_pb2.RemoveCustomDictionariesResponse,
    ]
    """여러 개를 한꺼번에 지운다."""
    CheckConflict: grpc.UnaryUnaryMultiCallable[
        bareun.custom_dict_pb2.CheckConflictRequest,
        bareun.custom_dict_pb2.CheckConflictResponse,
    ]
    """사용사 사전 사이의 충돌을 점검한다."""

class CustomDictionaryServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomDictionaryList(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.GetCustomDictionaryListResponse:
        """전체 목록을 다 가져오기"""
    @abc.abstractmethod
    def GetCustomDictionary(
        self,
        request: bareun.custom_dict_pb2.GetCustomDictionaryRequest,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.GetCustomDictionaryResponse:
        """현재 저장되어 있는 사전 하나만 가져온다."""
    @abc.abstractmethod
    def UpdateCustomDictionary(
        self,
        request: bareun.custom_dict_pb2.UpdateCustomDictionaryRequest,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.UpdateCustomDictionaryResponse:
        """전체를 모두 다 바꿔치기하는 경우"""
    @abc.abstractmethod
    def RemoveCustomDictionaries(
        self,
        request: bareun.custom_dict_pb2.RemoveCustomDictionariesRequest,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.RemoveCustomDictionariesResponse:
        """여러 개를 한꺼번에 지운다."""
    @abc.abstractmethod
    def CheckConflict(
        self,
        request: bareun.custom_dict_pb2.CheckConflictRequest,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.CheckConflictResponse:
        """사용사 사전 사이의 충돌을 점검한다."""

def add_CustomDictionaryServiceServicer_to_server(servicer: CustomDictionaryServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2019-present BAIKAL AI Inc."""
import bareun.dict_common_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CustomDictionaryMeta(google.protobuf.message.Message):
    """하나의 도메인용 커스텀 사전 데이터"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class DictMeta(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TYPE_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        ITEMS_COUNT_FIELD_NUMBER: builtins.int
        type: bareun.dict_common_pb2.DictType.ValueType
        """사전의 유형"""
        name: builtins.str
        """사전의 이름
        사전의 이름은 반드시 "[DomainName]-"로 시작해야 한다.
        사전의 이름은 다음 규칙에 따라서 만든다.
        고유명사는 np-set
        복합명사는 cp-set
        복합명사분리사전은 `cp-caret-set`
        """
        items_count: builtins.int
        """사전 데이터의 개수"""
        def __init__(
            self,
            *,
            type: bareun.dict_common_pb2.DictType.ValueType = ...,
            name: builtins.str = ...,
            items_count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["items_count", b"items_count", "name", b"name", "type", b"type"]) -> None: ...

    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    NP_SET_FIELD_NUMBER: builtins.int
    CP_SET_FIELD_NUMBER: builtins.int
    CP_CARET_SET_FIELD_NUMBER: builtins.int
    VV_SET_FIELD_NUMBER: builtins.int
    VA_SET_FIELD_NUMBER: builtins.int
    domain_name: builtins.str
    @property
    def np_set(self) -> global___CustomDictionaryMeta.DictMeta:
        """고유명사용 사전"""
    @property
    def cp_set(self) -> global___CustomDictionaryMeta.DictMeta:
        """복합명사용 사전"""
    @property
    def cp_caret_set(self) -> global___CustomDictionaryMeta.DictMeta:
        """복합명사 분리용 사전"""
    @property
    def vv_set(self) -> global___CustomDictionaryMeta.DictMeta:
        """동사 사전"""
    @property
    def va_set(self) -> global___CustomDictionaryMeta.DictMeta:
        """형용사 사전"""
    def __init__(
        self,
        *,
        domain_name: builtins.str = ...,
        np_set: global___CustomDictionaryMeta.DictMeta | None = ...,
        cp_set: global___CustomDictionaryMeta.DictMeta | None = ...,
        cp_caret_set: global___CustomDictionaryMeta.DictMeta | None = ...,
        vv_set: global___CustomDictionaryMeta.DictMeta | None = ...,
        va_set: global___CustomDictionaryMeta.DictMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cp_caret_set", b"cp_caret_set", "cp_set", b"cp_set", "np_set", b"np_set", "va_set", b"va_set", "vv_set", b"vv_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cp_caret_set", b"cp_caret_set", "cp_set", b"cp_set", "domain_name", b"domain_name", "np_set", b"np_set", "va_set", b"va_set", "vv_set", b"vv_set"]) -> None: ...

global___CustomDictionaryMeta = CustomDictionaryMeta

class CustomDictionary(google.protobuf.message.Message):
    """커스텀 사전의 데이터 전송 규격"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    NP_SET_FIELD_NUMBER: builtins.int
    CP_SET_FIELD_NUMBER: builtins.int
    CP_CARET_SET_FIELD_NUMBER: builtins.int
    VV_SET_FIELD_NUMBER: builtins.int
    VA_SET_FIELD_NUMBER: builtins.int
    MM_SET_FIELD_NUMBER: builtins.int
    MAG_SET_FIELD_NUMBER: builtins.int
    IC_SET_FIELD_NUMBER: builtins.int
    domain_name: builtins.str
    @property
    def np_set(self) -> bareun.dict_common_pb2.DictSet:
        """고유명사용 사전"""
    @property
    def cp_set(self) -> bareun.dict_common_pb2.DictSet:
        """복합명사용 사전"""
    @property
    def cp_caret_set(self) -> bareun.dict_common_pb2.DictSet:
        """복합명사 분리용 사전"""
    @property
    def vv_set(self) -> bareun.dict_common_pb2.DictSet:
        """동사 사전"""
    @property
    def va_set(self) -> bareun.dict_common_pb2.DictSet:
        """형용사 사전"""
    @property
    def mm_set(self) -> bareun.dict_common_pb2.DictSet:
        """관형사 사전"""
    @property
    def mag_set(self) -> bareun.dict_common_pb2.DictSet:
        """부사 사전"""
    @property
    def ic_set(self) -> bareun.dict_common_pb2.DictSet:
        """감탄사 사전"""
    def __init__(
        self,
        *,
        domain_name: builtins.str = ...,
        np_set: bareun.dict_common_pb2.DictSet | None = ...,
        cp_set: bareun.dict_common_pb2.DictSet | None = ...,
        cp_caret_set: bareun.dict_common_pb2.DictSet | None = ...,
        vv_set: bareun.dict_common_pb2.DictSet | None = ...,
        va_set: bareun.dict_common_pb2.DictSet | None = ...,
        mm_set: bareun.dict_common_pb2.DictSet | None = ...,
        mag_set: bareun.dict_common_pb2.DictSet | None = ...,
        ic_set: bareun.dict_common_pb2.DictSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cp_caret_set", b"cp_caret_set", "cp_set", b"cp_set", "ic_set", b"ic_set", "mag_set", b"mag_set", "mm_set", b"mm_set", "np_set", b"np_set", "va_set", b"va_set", "vv_set", b"vv_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cp_caret_set", b"cp_caret_set", "cp_set", b"cp_set", "domain_name", b"domain_name", "ic_set", b"ic_set", "mag_set", b"mag_set", "mm_set", b"mm_set", "np_set", b"np_set", "va_set", b"va_set", "vv_set", b"vv_set"]) -> None: ...

global___CustomDictionary = CustomDictionary

class CustomDictionaryMap(google.protobuf.message.Message):
    """
    프로세스 내부에서 서비스 중인 도메인 Dictionary 사전
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CustomDictMapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___CustomDictionary: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___CustomDictionary | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CUSTOM_DICT_MAP_FIELD_NUMBER: builtins.int
    @property
    def custom_dict_map(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___CustomDictionary]: ...
    def __init__(
        self,
        *,
        custom_dict_map: collections.abc.Mapping[builtins.str, global___CustomDictionary] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_dict_map", b"custom_dict_map"]) -> None: ...

global___CustomDictionaryMap = CustomDictionaryMap

class GetCustomDictionaryListResponse(google.protobuf.message.Message):
    """커스텀 사전 목록을 가져온다."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_DICTS_FIELD_NUMBER: builtins.int
    @property
    def domain_dicts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomDictionaryMeta]: ...
    def __init__(
        self,
        *,
        domain_dicts: collections.abc.Iterable[global___CustomDictionaryMeta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_dicts", b"domain_dicts"]) -> None: ...

global___GetCustomDictionaryListResponse = GetCustomDictionaryListResponse

class GetCustomDictionaryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    domain_name: builtins.str
    def __init__(
        self,
        *,
        domain_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name", b"domain_name"]) -> None: ...

global___GetCustomDictionaryRequest = GetCustomDictionaryRequest

class GetCustomDictionaryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    DICT_FIELD_NUMBER: builtins.int
    domain_name: builtins.str
    @property
    def dict(self) -> global___CustomDictionary: ...
    def __init__(
        self,
        *,
        domain_name: builtins.str = ...,
        dict: global___CustomDictionary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dict", b"dict"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dict", b"dict", "domain_name", b"domain_name"]) -> None: ...

global___GetCustomDictionaryResponse = GetCustomDictionaryResponse

class UpdateCustomDictionaryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    DICT_FIELD_NUMBER: builtins.int
    domain_name: builtins.str
    @property
    def dict(self) -> global___CustomDictionary: ...
    def __init__(
        self,
        *,
        domain_name: builtins.str = ...,
        dict: global___CustomDictionary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dict", b"dict"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dict", b"dict", "domain_name", b"domain_name"]) -> None: ...

global___UpdateCustomDictionaryRequest = UpdateCustomDictionaryRequest

class UpdateCustomDictionaryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATED_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    updated_domain_name: builtins.str
    def __init__(
        self,
        *,
        updated_domain_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["updated_domain_name", b"updated_domain_name"]) -> None: ...

global___UpdateCustomDictionaryResponse = UpdateCustomDictionaryResponse

class RemoveCustomDictionariesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAMES_FIELD_NUMBER: builtins.int
    ALL_FIELD_NUMBER: builtins.int
    @property
    def domain_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    all: builtins.bool
    def __init__(
        self,
        *,
        domain_names: collections.abc.Iterable[builtins.str] | None = ...,
        all: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "domain_names", b"domain_names"]) -> None: ...

global___RemoveCustomDictionariesRequest = RemoveCustomDictionariesRequest

class RemoveCustomDictionariesResponse(google.protobuf.message.Message):
    """삭제된 커스텀 사전의 목록"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class DeletedDomainNamesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.bool
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DELETED_DOMAIN_NAMES_FIELD_NUMBER: builtins.int
    @property
    def deleted_domain_names(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.bool]: ...
    def __init__(
        self,
        *,
        deleted_domain_names: collections.abc.Mapping[builtins.str, builtins.bool] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted_domain_names", b"deleted_domain_names"]) -> None: ...

global___RemoveCustomDictionariesResponse = RemoveCustomDictionariesResponse

class CheckConflictRequest(google.protobuf.message.Message):
    """사용자 사전의 충돌을 점검하기 위한 요청"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAMES_FIELD_NUMBER: builtins.int
    @property
    def domain_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """비교할 사전들의 목록
        사전의 내부에서도 비교를 할 수 있기 때문에 하나로도 충분하다.
        """
    def __init__(
        self,
        *,
        domain_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_names", b"domain_names"]) -> None: ...

global___CheckConflictRequest = CheckConflictRequest

class CheckConflictResponse(google.protobuf.message.Message):
    """사용자 사전의 충돌 점검 응답"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFLICTS_FIELD_NUMBER: builtins.int
    @property
    def conflicts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Conflict]:
        """전체 충돌의 내욤"""
    def __init__(
        self,
        *,
        conflicts: collections.abc.Iterable[global___Conflict] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["conflicts", b"conflicts"]) -> None: ...

global___CheckConflictResponse = CheckConflictResponse

class DictOne(google.protobuf.message.Message):
    """비교대상 사전 기본 정보"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DICT_NAME_FIELD_NUMBER: builtins.int
    DICT_SET_NAME_FIELD_NUMBER: builtins.int
    dict_name: builtins.str
    """도메인 이름"""
    dict_set_name: builtins.str
    """사전의 이름 (np_set 등)"""
    def __init__(
        self,
        *,
        dict_name: builtins.str = ...,
        dict_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dict_name", b"dict_name", "dict_set_name", b"dict_set_name"]) -> None: ...

global___DictOne = DictOne

class Conflict(google.protobuf.message.Message):
    """하나의 충돌에 대한 설정"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEFT_FIELD_NUMBER: builtins.int
    RIGHT_FIELD_NUMBER: builtins.int
    LEFT_WORD_FIELD_NUMBER: builtins.int
    RIGHT_WORD_FIELD_NUMBER: builtins.int
    CONFLICT_FIELD_NUMBER: builtins.int
    DUPLICATED_FIELD_NUMBER: builtins.int
    CONFLICT_MSG_FIELD_NUMBER: builtins.int
    @property
    def left(self) -> global___DictOne:
        """비교의 왼쪽"""
    @property
    def right(self) -> global___DictOne:
        """비교의 오른쪽"""
    left_word: builtins.str
    """단어 왼쪽"""
    right_word: builtins.str
    """단어 오른쪽"""
    conflict: builtins.bool
    """충돌인가?"""
    duplicated: builtins.bool
    """중복인가?"""
    conflict_msg: builtins.str
    """오류 메시지"""
    def __init__(
        self,
        *,
        left: global___DictOne | None = ...,
        right: global___DictOne | None = ...,
        left_word: builtins.str = ...,
        right_word: builtins.str = ...,
        conflict: builtins.bool = ...,
        duplicated: builtins.bool = ...,
        conflict_msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["left", b"left", "right", b"right"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conflict", b"conflict", "conflict_msg", b"conflict_msg", "duplicated", b"duplicated", "left", b"left", "left_word", b"left_word", "right", b"right", "right_word", b"right_word"]) -> None: ...

global___Conflict = Conflict



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bareun/language_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from bareun import lang_common_pb2 as bareun_dot_lang__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x62\x61reun/language_service.proto\x12\x06\x62\x61reun\x1a\x1cgoogle/api/annotations.proto\x1a\x18\x62\x61reun/lang_common.proto\"Z\n\x08Sentence\x12\x1e\n\x04text\x18\x01 \x01(\x0b\x32\x10.bareun.TextSpan\x12\x1d\n\x06tokens\x18\x02 \x03(\x0b\x32\r.bareun.Token\x12\x0f\n\x07refined\x18\x03 \x01(\t\"\xc9\x05\n\x08Morpheme\x12\x1e\n\x04text\x18\x01 \x01(\x0b\x32\x10.bareun.TextSpan\x12!\n\x03tag\x18\x02 \x01(\x0e\x32\x14.bareun.Morpheme.Tag\x12\x13\n\x0bprobability\x18\x03 \x01(\x02\x12\x31\n\x0cout_of_vocab\x18\x05 \x01(\x0e\x32\x1b.bareun.Morpheme.OutOfVocab\x12\x1d\n\x10\x63ustom_dict_name\x18\x06 \x01(\tH\x00\x88\x01\x01\"^\n\nOutOfVocab\x12\x15\n\x11IN_WORD_EMBEDDING\x10\x00\x12\x10\n\x0cOUT_OF_VOCAB\x10\x01\x12\x12\n\x0eIN_CUSTOM_DICT\x10\x02\x12\x13\n\x0fIN_BUILTIN_DICT\x10\x03\"\x9d\x03\n\x03Tag\x12\x07\n\x03UNK\x10\x00\x12\x07\n\x03NNG\x10\x18\x12\x07\n\x03NNP\x10\x19\x12\x07\n\x03NNB\x10\x17\x12\x06\n\x02NP\x10\x1a\x12\x06\n\x02NR\x10\x1b\x12\x06\n\x02NF\x10\x16\x12\x06\n\x02NA\x10\x15\x12\x06\n\x02NV\x10\x1c\x12\x06\n\x02VV\x10)\x12\x06\n\x02VA\x10&\x12\x06\n\x02VX\x10*\x12\x07\n\x03VCP\x10(\x12\x07\n\x03VCN\x10\'\x12\x07\n\x03MMA\x10\x12\x12\x07\n\x03MMD\x10\x13\x12\x07\n\x03MMN\x10\x14\x12\x07\n\x03MAG\x10\x10\x12\x07\n\x03MAJ\x10\x11\x12\x06\n\x02IC\x10\x06\x12\x07\n\x03JKS\x10\r\x12\x07\n\x03JKC\x10\t\x12\x07\n\x03JKG\x10\n\x12\x07\n\x03JKO\x10\x0b\x12\x07\n\x03JKB\x10\x08\x12\x07\n\x03JKV\x10\x0e\x12\x07\n\x03JKQ\x10\x0c\x12\x06\n\x02JX\x10\x0f\x12\x06\n\x02JC\x10\x07\x12\x06\n\x02\x45P\x10\x03\x12\x06\n\x02\x45\x46\x10\x02\x12\x06\n\x02\x45\x43\x10\x01\x12\x07\n\x03\x45TN\x10\x05\x12\x07\n\x03\x45TM\x10\x04\x12\x07\n\x03XPN\x10+\x12\x07\n\x03XSN\x10.\x12\x07\n\x03XSV\x10/\x12\x07\n\x03XSA\x10-\x12\x06\n\x02XR\x10,\x12\x06\n\x02SF\x10\x1e\x12\x06\n\x02SP\x10#\x12\x06\n\x02SS\x10$\x12\x06\n\x02SE\x10\x1d\x12\x06\n\x02SO\x10\"\x12\x06\n\x02SW\x10%\x12\x06\n\x02SL\x10 \x12\x06\n\x02SH\x10\x1f\x12\x06\n\x02SN\x10!B\x13\n\x11_custom_dict_name\"}\n\x05Token\x12\x1e\n\x04text\x18\x01 \x01(\x0b\x32\x10.bareun.TextSpan\x12#\n\tmorphemes\x18\x02 \x03(\x0b\x32\x10.bareun.Morpheme\x12\r\n\x05lemma\x18\x04 \x01(\t\x12\x0e\n\x06tagged\x18\x05 \x01(\t\x12\x10\n\x08modified\x18\x0b \x01(\t\"\xe7\x01\n\x14\x41nalyzeSyntaxRequest\x12\"\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x10.bareun.Document\x12+\n\rencoding_type\x18\x02 \x01(\x0e\x32\x14.bareun.EncodingType\x12\x1b\n\x13\x61uto_split_sentence\x18\x03 \x01(\x08\x12\x19\n\rcustom_domain\x18\x04 \x01(\tB\x02\x18\x01\x12\x14\n\x0c\x61uto_spacing\x18\x05 \x01(\x08\x12\x15\n\rauto_jointing\x18\x06 \x01(\x08\x12\x19\n\x11\x63ustom_dict_names\x18\x0b \x03(\t\"N\n\x15\x41nalyzeSyntaxResponse\x12#\n\tsentences\x18\x01 \x03(\x0b\x32\x10.bareun.Sentence\x12\x10\n\x08language\x18\x03 \x01(\t\"\xcf\x01\n\x18\x41nalyzeSyntaxListRequest\x12\x11\n\tsentences\x18\x01 \x03(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12+\n\rencoding_type\x18\x03 \x01(\x0e\x32\x14.bareun.EncodingType\x12\x19\n\rcustom_domain\x18\x04 \x01(\tB\x02\x18\x01\x12\x14\n\x0c\x61uto_spacing\x18\x05 \x01(\x08\x12\x15\n\rauto_jointing\x18\x06 \x01(\x08\x12\x19\n\x11\x63ustom_dict_names\x18\x0b \x03(\t\"R\n\x19\x41nalyzeSyntaxListResponse\x12#\n\tsentences\x18\x01 \x03(\x0b\x32\x10.bareun.Sentence\x12\x10\n\x08language\x18\x03 \x01(\t\"\x95\x01\n\x0fTokenizeRequest\x12\"\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x10.bareun.Document\x12+\n\rencoding_type\x18\x02 \x01(\x0e\x32\x14.bareun.EncodingType\x12\x1b\n\x13\x61uto_split_sentence\x18\x03 \x01(\x08\x12\x14\n\x0c\x61uto_spacing\x18\x05 \x01(\x08\"7\n\x07Segment\x12\x1e\n\x04text\x18\x01 \x01(\x0b\x32\x10.bareun.TextSpan\x12\x0c\n\x04hint\x18\x02 \x01(\t\"a\n\x0cSegmentToken\x12\x1e\n\x04text\x18\x01 \x01(\x0b\x32\x10.bareun.TextSpan\x12!\n\x08segments\x18\x02 \x03(\x0b\x32\x0f.bareun.Segment\x12\x0e\n\x06tagged\x18\x05 \x01(\t\"W\n\x0fSegmentSentence\x12\x1e\n\x04text\x18\x01 \x01(\x0b\x32\x10.bareun.TextSpan\x12$\n\x06tokens\x18\x02 \x03(\x0b\x32\x14.bareun.SegmentToken\"P\n\x10TokenizeResponse\x12*\n\tsentences\x18\x01 \x03(\x0b\x32\x17.bareun.SegmentSentence\x12\x10\n\x08language\x18\x03 \x01(\t2\xe8\x02\n\x0fLanguageService\x12o\n\rAnalyzeSyntax\x12\x1c.bareun.AnalyzeSyntaxRequest\x1a\x1d.bareun.AnalyzeSyntaxResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/bareun/api/v1/analyze:\x01*\x12\x80\x01\n\x11\x41nalyzeSyntaxList\x12 .bareun.AnalyzeSyntaxListRequest\x1a!.bareun.AnalyzeSyntaxListResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/bareun/api/v1/analyze-list:\x01*\x12\x61\n\x08Tokenize\x12\x17.bareun.TokenizeRequest\x1a\x18.bareun.TokenizeResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/bareun/api/v1/tokenize:\x01*BB\n\x10\x61i.bareun.protosB\x14LanguageServiceProtoP\x01Z\x16\x62\x61reun.ai/proto/bareunb\x06proto3')



_SENTENCE = DESCRIPTOR.message_types_by_name['Sentence']
_MORPHEME = DESCRIPTOR.message_types_by_name['Morpheme']
_TOKEN = DESCRIPTOR.message_types_by_name['Token']
_ANALYZESYNTAXREQUEST = DESCRIPTOR.message_types_by_name['AnalyzeSyntaxRequest']
_ANALYZESYNTAXRESPONSE = DESCRIPTOR.message_types_by_name['AnalyzeSyntaxResponse']
_ANALYZESYNTAXLISTREQUEST = DESCRIPTOR.message_types_by_name['AnalyzeSyntaxListRequest']
_ANALYZESYNTAXLISTRESPONSE = DESCRIPTOR.message_types_by_name['AnalyzeSyntaxListResponse']
_TOKENIZEREQUEST = DESCRIPTOR.message_types_by_name['TokenizeRequest']
_SEGMENT = DESCRIPTOR.message_types_by_name['Segment']
_SEGMENTTOKEN = DESCRIPTOR.message_types_by_name['SegmentToken']
_SEGMENTSENTENCE = DESCRIPTOR.message_types_by_name['SegmentSentence']
_TOKENIZERESPONSE = DESCRIPTOR.message_types_by_name['TokenizeResponse']
_MORPHEME_OUTOFVOCAB = _MORPHEME.enum_types_by_name['OutOfVocab']
_MORPHEME_TAG = _MORPHEME.enum_types_by_name['Tag']
Sentence = _reflection.GeneratedProtocolMessageType('Sentence', (_message.Message,), {
  'DESCRIPTOR' : _SENTENCE,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.Sentence)
  })
_sym_db.RegisterMessage(Sentence)

Morpheme = _reflection.GeneratedProtocolMessageType('Morpheme', (_message.Message,), {
  'DESCRIPTOR' : _MORPHEME,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.Morpheme)
  })
_sym_db.RegisterMessage(Morpheme)

Token = _reflection.GeneratedProtocolMessageType('Token', (_message.Message,), {
  'DESCRIPTOR' : _TOKEN,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.Token)
  })
_sym_db.RegisterMessage(Token)

AnalyzeSyntaxRequest = _reflection.GeneratedProtocolMessageType('AnalyzeSyntaxRequest', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZESYNTAXREQUEST,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.AnalyzeSyntaxRequest)
  })
_sym_db.RegisterMessage(AnalyzeSyntaxRequest)

AnalyzeSyntaxResponse = _reflection.GeneratedProtocolMessageType('AnalyzeSyntaxResponse', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZESYNTAXRESPONSE,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.AnalyzeSyntaxResponse)
  })
_sym_db.RegisterMessage(AnalyzeSyntaxResponse)

AnalyzeSyntaxListRequest = _reflection.GeneratedProtocolMessageType('AnalyzeSyntaxListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZESYNTAXLISTREQUEST,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.AnalyzeSyntaxListRequest)
  })
_sym_db.RegisterMessage(AnalyzeSyntaxListRequest)

AnalyzeSyntaxListResponse = _reflection.GeneratedProtocolMessageType('AnalyzeSyntaxListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZESYNTAXLISTRESPONSE,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.AnalyzeSyntaxListResponse)
  })
_sym_db.RegisterMessage(AnalyzeSyntaxListResponse)

TokenizeRequest = _reflection.GeneratedProtocolMessageType('TokenizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOKENIZEREQUEST,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.TokenizeRequest)
  })
_sym_db.RegisterMessage(TokenizeRequest)

Segment = _reflection.GeneratedProtocolMessageType('Segment', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENT,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.Segment)
  })
_sym_db.RegisterMessage(Segment)

SegmentToken = _reflection.GeneratedProtocolMessageType('SegmentToken', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTTOKEN,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.SegmentToken)
  })
_sym_db.RegisterMessage(SegmentToken)

SegmentSentence = _reflection.GeneratedProtocolMessageType('SegmentSentence', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTSENTENCE,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.SegmentSentence)
  })
_sym_db.RegisterMessage(SegmentSentence)

TokenizeResponse = _reflection.GeneratedProtocolMessageType('TokenizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOKENIZERESPONSE,
  '__module__' : 'bareun.language_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.TokenizeResponse)
  })
_sym_db.RegisterMessage(TokenizeResponse)

_LANGUAGESERVICE = DESCRIPTOR.services_by_name['LanguageService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020ai.bareun.protosB\024LanguageServiceProtoP\001Z\026bareun.ai/proto/bareun'
  _ANALYZESYNTAXREQUEST.fields_by_name['custom_domain']._options = None
  _ANALYZESYNTAXREQUEST.fields_by_name['custom_domain']._serialized_options = b'\030\001'
  _ANALYZESYNTAXLISTREQUEST.fields_by_name['custom_domain']._options = None
  _ANALYZESYNTAXLISTREQUEST.fields_by_name['custom_domain']._serialized_options = b'\030\001'
  _LANGUAGESERVICE.methods_by_name['AnalyzeSyntax']._options = None
  _LANGUAGESERVICE.methods_by_name['AnalyzeSyntax']._serialized_options = b'\202\323\344\223\002\033\"\026/bareun/api/v1/analyze:\001*'
  _LANGUAGESERVICE.methods_by_name['AnalyzeSyntaxList']._options = None
  _LANGUAGESERVICE.methods_by_name['AnalyzeSyntaxList']._serialized_options = b'\202\323\344\223\002 \"\033/bareun/api/v1/analyze-list:\001*'
  _LANGUAGESERVICE.methods_by_name['Tokenize']._options = None
  _LANGUAGESERVICE.methods_by_name['Tokenize']._serialized_options = b'\202\323\344\223\002\034\"\027/bareun/api/v1/tokenize:\001*'
  _SENTENCE._serialized_start=97
  _SENTENCE._serialized_end=187
  _MORPHEME._serialized_start=190
  _MORPHEME._serialized_end=903
  _MORPHEME_OUTOFVOCAB._serialized_start=372
  _MORPHEME_OUTOFVOCAB._serialized_end=466
  _MORPHEME_TAG._serialized_start=469
  _MORPHEME_TAG._serialized_end=882
  _TOKEN._serialized_start=905
  _TOKEN._serialized_end=1030
  _ANALYZESYNTAXREQUEST._serialized_start=1033
  _ANALYZESYNTAXREQUEST._serialized_end=1264
  _ANALYZESYNTAXRESPONSE._serialized_start=1266
  _ANALYZESYNTAXRESPONSE._serialized_end=1344
  _ANALYZESYNTAXLISTREQUEST._serialized_start=1347
  _ANALYZESYNTAXLISTREQUEST._serialized_end=1554
  _ANALYZESYNTAXLISTRESPONSE._serialized_start=1556
  _ANALYZESYNTAXLISTRESPONSE._serialized_end=1638
  _TOKENIZEREQUEST._serialized_start=1641
  _TOKENIZEREQUEST._serialized_end=1790
  _SEGMENT._serialized_start=1792
  _SEGMENT._serialized_end=1847
  _SEGMENTTOKEN._serialized_start=1849
  _SEGMENTTOKEN._serialized_end=1946
  _SEGMENTSENTENCE._serialized_start=1948
  _SEGMENTSENTENCE._serialized_end=2035
  _TOKENIZERESPONSE._serialized_start=2037
  _TOKENIZERESPONSE._serialized_end=2117
  _LANGUAGESERVICE._serialized_start=2120
  _LANGUAGESERVICE._serialized_end=2480
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bareun import language_service_pb2 as bareun_dot_language__service__pb2


class LanguageServiceStub(object):
    """한국어에 대한 분석 서비스를 제공하는 서비스.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AnalyzeSyntax = channel.unary_unary(
                '/bareun.LanguageService/AnalyzeSyntax',
                request_serializer=bareun_dot_language__service__pb2.AnalyzeSyntaxRequest.SerializeToString,
                response_deserializer=bareun_dot_language__service__pb2.AnalyzeSyntaxResponse.FromString,
                )
        self.AnalyzeSyntaxList = channel.unary_unary(
                '/bareun.LanguageService/AnalyzeSyntaxList',
                request_serializer=bareun_dot_language__service__pb2.AnalyzeSyntaxListRequest.SerializeToString,
                response_deserializer=bareun_dot_language__service__pb2.AnalyzeSyntaxListResponse.FromString,
                )
        self.Tokenize = channel.unary_unary(
                '/bareun.LanguageService/Tokenize',
                request_serializer=bareun_dot_language__service__pb2.TokenizeRequest.SerializeToString,
                response_deserializer=bareun_dot_language__service__pb2.TokenizeResponse.FromString,
                )


class LanguageServiceServicer(object):
    """한국어에 대한 분석 서비스를 제공하는 서비스.
    """

    def AnalyzeSyntax(self, request, context):
        """텍스트의 형태를 분석하고, 문장 경계를 파악하여 토큰 단위로 잘라낸다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AnalyzeSyntaxList(self, request, context):
        """복수의 문장을 대상으로 텍스트의 형태를 분석하고, 토큰 단위로 잘라낸다.
        복수의 문장에 대한 순서를 그대로 반환하고 문장을 분할하지 않는다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Tokenize(self, request, context):
        """한국어의 특성에 따라서 텍스트를 분절 단뤼로 구분해 낸다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LanguageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AnalyzeSyntax': grpc.unary_unary_rpc_method_handler(
                    servicer.AnalyzeSyntax,
                    request_deserializer=bareun_dot_language__service__pb2.AnalyzeSyntaxRequest.FromString,
                    response_serializer=bareun_dot_language__service__pb2.AnalyzeSyntaxResponse.SerializeToString,
            ),
            'AnalyzeSyntaxList': grpc.unary_unary_rpc_method_handler(
                    servicer.AnalyzeSyntaxList,
                    request_deserializer=bareun_dot_language__service__pb2.AnalyzeSyntaxListRequest.FromString,
                    response_serializer=bareun_dot_language__service__pb2.AnalyzeSyntaxListResponse.SerializeToString,
            ),
            'Tokenize': grpc.unary_unary_rpc_method_handler(
                    servicer.Tokenize,
                    request_deserializer=bareun_dot_language__service__pb2.TokenizeRequest.FromString,
                    response_serializer=bareun_dot_language__service__pb2.TokenizeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bareun.LanguageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LanguageService(object):
    """한국어에 대한 분석 서비스를 제공하는 서비스.
    """

    @staticmethod
    def AnalyzeSyntax(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.LanguageService/AnalyzeSyntax',
            bareun_dot_language__service__pb2.AnalyzeSyntaxRequest.SerializeToString,
            bareun_dot_language__service__pb2.AnalyzeSyntaxResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AnalyzeSyntaxList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.LanguageService/AnalyzeSyntaxList',
            bareun_dot_language__service__pb2.AnalyzeSyntaxListRequest.SerializeToString,
            bareun_dot_language__service__pb2.AnalyzeSyntaxListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Tokenize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.LanguageService/Tokenize',
            bareun_dot_language__service__pb2.TokenizeRequest.SerializeToString,
            bareun_dot_language__service__pb2.TokenizeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2019-present BAIKAL AI Inc."""
import bareun.lang_common_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Sentence(google.protobuf.message.Message):
    """################################################################ #
    입력 문서에 분석된 문장
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TOKENS_FIELD_NUMBER: builtins.int
    REFINED_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> bareun.lang_common_pb2.TextSpan:
        """The sentence text."""
    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Token]:
        """어절단위로 쪼개는 것은"""
    refined: builtins.str
    """띄어쓰기 등의 오류를 수정한 결과물"""
    def __init__(
        self,
        *,
        text: bareun.lang_common_pb2.TextSpan | None = ...,
        tokens: collections.abc.Iterable[global___Token] | None = ...,
        refined: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["refined", b"refined", "text", b"text", "tokens", b"tokens"]) -> None: ...

global___Sentence = Sentence

class Morpheme(google.protobuf.message.Message):
    """형태소"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _OutOfVocab:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OutOfVocabEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Morpheme._OutOfVocab.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IN_WORD_EMBEDDING: Morpheme._OutOfVocab.ValueType  # 0
        """워드 임베딩에 포함된 내용"""
        OUT_OF_VOCAB: Morpheme._OutOfVocab.ValueType  # 1
        """자동 추측, 미등록 단어"""
        IN_CUSTOM_DICT: Morpheme._OutOfVocab.ValueType  # 2
        """사용자 제공 사전에 있는 내용"""
        IN_BUILTIN_DICT: Morpheme._OutOfVocab.ValueType  # 3
        """기본 사전에 포함된 내용"""

    class OutOfVocab(_OutOfVocab, metaclass=_OutOfVocabEnumTypeWrapper):
        """사전에 없는 단어 정보 처리 결과"""

    IN_WORD_EMBEDDING: Morpheme.OutOfVocab.ValueType  # 0
    """워드 임베딩에 포함된 내용"""
    OUT_OF_VOCAB: Morpheme.OutOfVocab.ValueType  # 1
    """자동 추측, 미등록 단어"""
    IN_CUSTOM_DICT: Morpheme.OutOfVocab.ValueType  # 2
    """사용자 제공 사전에 있는 내용"""
    IN_BUILTIN_DICT: Morpheme.OutOfVocab.ValueType  # 3
    """기본 사전에 포함된 내용"""

    class _Tag:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TagEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Morpheme._Tag.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNK: Morpheme._Tag.ValueType  # 0
        """// 0 1 EC
        // 1 2 EF
        // 2 3 EP
        // 3 4 ETM
        // 4 5 ETN
        // 5 6 IC
        // 6 7 JC
        // 7 8 JKB
        // 8 9 JKC
        // 9 10 JKG
        // 10 11 JKO
        // 11 12 JKQ
        // 12 13 JKS
        // 13 14 JKV
        // 14 15 JX
        // 15 16 MAG
        // 16 17 MAJ
        // 17 18 MMA
        // 18 19 MMD
        // 19 20 MMN
        // 20 21 NA
        // 21 22 NF
        // 22 23 NNB
        // 23 24 NNG
        // 24 25 NNP
        // 25 26 NP
        // 26 27 NR
        // 27 28 NV
        // 28 29 SE
        // 29 30 SF
        // 30 31 SH
        // 31 32 SL
        // 32 33 SN
        // 33 34 SO
        // 34 35 SP
        // 35 36 SS
        // 36 37 SW
        // 37 38 VA
        // 38 39 VCN
        // 39 40 VCP
        // 40 41 VV
        // 41 42 VX
        // 42 43 XPN
        // 43 44 XR
        // 44 45 XSA
        // 45 46 XSN
        // 46 47 XSV
        """
        NNG: Morpheme._Tag.ValueType  # 24
        """일반 명사"""
        NNP: Morpheme._Tag.ValueType  # 25
        """고유 명사"""
        NNB: Morpheme._Tag.ValueType  # 23
        """의존 명사"""
        NP: Morpheme._Tag.ValueType  # 26
        """대명사"""
        NR: Morpheme._Tag.ValueType  # 27
        """수사"""
        NF: Morpheme._Tag.ValueType  # 22
        """명사 추정 범주"""
        NA: Morpheme._Tag.ValueType  # 21
        """분석불능범주"""
        NV: Morpheme._Tag.ValueType  # 28
        """용언 추정 범주"""
        VV: Morpheme._Tag.ValueType  # 41
        """동사"""
        VA: Morpheme._Tag.ValueType  # 38
        """형용사"""
        VX: Morpheme._Tag.ValueType  # 42
        """보조 용언"""
        VCP: Morpheme._Tag.ValueType  # 40
        """긍정 지정사"""
        VCN: Morpheme._Tag.ValueType  # 39
        """부정 지정사"""
        MMA: Morpheme._Tag.ValueType  # 18
        """성상 관형사"""
        MMD: Morpheme._Tag.ValueType  # 19
        """지시 관형사"""
        MMN: Morpheme._Tag.ValueType  # 20
        """수 관형사"""
        MAG: Morpheme._Tag.ValueType  # 16
        """일반 부사"""
        MAJ: Morpheme._Tag.ValueType  # 17
        """접속 부사"""
        IC: Morpheme._Tag.ValueType  # 6
        """감탄사"""
        JKS: Morpheme._Tag.ValueType  # 13
        """주격 조사"""
        JKC: Morpheme._Tag.ValueType  # 9
        """보격 조사"""
        JKG: Morpheme._Tag.ValueType  # 10
        """관형격 조사"""
        JKO: Morpheme._Tag.ValueType  # 11
        """목적격 조사"""
        JKB: Morpheme._Tag.ValueType  # 8
        """부사격 조사"""
        JKV: Morpheme._Tag.ValueType  # 14
        """호격 조사"""
        JKQ: Morpheme._Tag.ValueType  # 12
        """인용격 조사"""
        JX: Morpheme._Tag.ValueType  # 15
        """보조사"""
        JC: Morpheme._Tag.ValueType  # 7
        """접속 조사"""
        EP: Morpheme._Tag.ValueType  # 3
        """선어말 어미"""
        EF: Morpheme._Tag.ValueType  # 2
        """종결 어미"""
        EC: Morpheme._Tag.ValueType  # 1
        """연결 어미"""
        ETN: Morpheme._Tag.ValueType  # 5
        """명사형 전성 어미"""
        ETM: Morpheme._Tag.ValueType  # 4
        """관형형 전성 어미"""
        XPN: Morpheme._Tag.ValueType  # 43
        """체언 접두사"""
        XSN: Morpheme._Tag.ValueType  # 46
        """명사 파생 접미사"""
        XSV: Morpheme._Tag.ValueType  # 47
        """동사 파생 접미사"""
        XSA: Morpheme._Tag.ValueType  # 45
        """형용사 파생 접미사"""
        XR: Morpheme._Tag.ValueType  # 44
        """어근"""
        SF: Morpheme._Tag.ValueType  # 30
        """마침표,물음표,느낌표"""
        SP: Morpheme._Tag.ValueType  # 35
        """쉼표,가운뎃점,콜론,빗금"""
        SS: Morpheme._Tag.ValueType  # 36
        """따옴표,괄호표,줄표"""
        SE: Morpheme._Tag.ValueType  # 29
        """줄임표"""
        SO: Morpheme._Tag.ValueType  # 34
        """붙임표(물결,숨김,빠짐)"""
        SW: Morpheme._Tag.ValueType  # 37
        """기타기호 (논리수학기호,화폐기호)"""
        SL: Morpheme._Tag.ValueType  # 32
        """외국어"""
        SH: Morpheme._Tag.ValueType  # 31
        """한자"""
        SN: Morpheme._Tag.ValueType  # 33
        """숫자"""

    class Tag(_Tag, metaclass=_TagEnumTypeWrapper):
        """내부적으로 pred 된 형태소는 0~46까지 반환하지만,
        1~47까지 숫자로 쓰고, UNK은 0으로 바꾼다.
        """

    UNK: Morpheme.Tag.ValueType  # 0
    """// 0 1 EC
    // 1 2 EF
    // 2 3 EP
    // 3 4 ETM
    // 4 5 ETN
    // 5 6 IC
    // 6 7 JC
    // 7 8 JKB
    // 8 9 JKC
    // 9 10 JKG
    // 10 11 JKO
    // 11 12 JKQ
    // 12 13 JKS
    // 13 14 JKV
    // 14 15 JX
    // 15 16 MAG
    // 16 17 MAJ
    // 17 18 MMA
    // 18 19 MMD
    // 19 20 MMN
    // 20 21 NA
    // 21 22 NF
    // 22 23 NNB
    // 23 24 NNG
    // 24 25 NNP
    // 25 26 NP
    // 26 27 NR
    // 27 28 NV
    // 28 29 SE
    // 29 30 SF
    // 30 31 SH
    // 31 32 SL
    // 32 33 SN
    // 33 34 SO
    // 34 35 SP
    // 35 36 SS
    // 36 37 SW
    // 37 38 VA
    // 38 39 VCN
    // 39 40 VCP
    // 40 41 VV
    // 41 42 VX
    // 42 43 XPN
    // 43 44 XR
    // 44 45 XSA
    // 45 46 XSN
    // 46 47 XSV
    """
    NNG: Morpheme.Tag.ValueType  # 24
    """일반 명사"""
    NNP: Morpheme.Tag.ValueType  # 25
    """고유 명사"""
    NNB: Morpheme.Tag.ValueType  # 23
    """의존 명사"""
    NP: Morpheme.Tag.ValueType  # 26
    """대명사"""
    NR: Morpheme.Tag.ValueType  # 27
    """수사"""
    NF: Morpheme.Tag.ValueType  # 22
    """명사 추정 범주"""
    NA: Morpheme.Tag.ValueType  # 21
    """분석불능범주"""
    NV: Morpheme.Tag.ValueType  # 28
    """용언 추정 범주"""
    VV: Morpheme.Tag.ValueType  # 41
    """동사"""
    VA: Morpheme.Tag.ValueType  # 38
    """형용사"""
    VX: Morpheme.Tag.ValueType  # 42
    """보조 용언"""
    VCP: Morpheme.Tag.ValueType  # 40
    """긍정 지정사"""
    VCN: Morpheme.Tag.ValueType  # 39
    """부정 지정사"""
    MMA: Morpheme.Tag.ValueType  # 18
    """성상 관형사"""
    MMD: Morpheme.Tag.ValueType  # 19
    """지시 관형사"""
    MMN: Morpheme.Tag.ValueType  # 20
    """수 관형사"""
    MAG: Morpheme.Tag.ValueType  # 16
    """일반 부사"""
    MAJ: Morpheme.Tag.ValueType  # 17
    """접속 부사"""
    IC: Morpheme.Tag.ValueType  # 6
    """감탄사"""
    JKS: Morpheme.Tag.ValueType  # 13
    """주격 조사"""
    JKC: Morpheme.Tag.ValueType  # 9
    """보격 조사"""
    JKG: Morpheme.Tag.ValueType  # 10
    """관형격 조사"""
    JKO: Morpheme.Tag.ValueType  # 11
    """목적격 조사"""
    JKB: Morpheme.Tag.ValueType  # 8
    """부사격 조사"""
    JKV: Morpheme.Tag.ValueType  # 14
    """호격 조사"""
    JKQ: Morpheme.Tag.ValueType  # 12
    """인용격 조사"""
    JX: Morpheme.Tag.ValueType  # 15
    """보조사"""
    JC: Morpheme.Tag.ValueType  # 7
    """접속 조사"""
    EP: Morpheme.Tag.ValueType  # 3
    """선어말 어미"""
    EF: Morpheme.Tag.ValueType  # 2
    """종결 어미"""
    EC: Morpheme.Tag.ValueType  # 1
    """연결 어미"""
    ETN: Morpheme.Tag.ValueType  # 5
    """명사형 전성 어미"""
    ETM: Morpheme.Tag.ValueType  # 4
    """관형형 전성 어미"""
    XPN: Morpheme.Tag.ValueType  # 43
    """체언 접두사"""
    XSN: Morpheme.Tag.ValueType  # 46
    """명사 파생 접미사"""
    XSV: Morpheme.Tag.ValueType  # 47
    """동사 파생 접미사"""
    XSA: Morpheme.Tag.ValueType  # 45
    """형용사 파생 접미사"""
    XR: Morpheme.Tag.ValueType  # 44
    """어근"""
    SF: Morpheme.Tag.ValueType  # 30
    """마침표,물음표,느낌표"""
    SP: Morpheme.Tag.ValueType  # 35
    """쉼표,가운뎃점,콜론,빗금"""
    SS: Morpheme.Tag.ValueType  # 36
    """따옴표,괄호표,줄표"""
    SE: Morpheme.Tag.ValueType  # 29
    """줄임표"""
    SO: Morpheme.Tag.ValueType  # 34
    """붙임표(물결,숨김,빠짐)"""
    SW: Morpheme.Tag.ValueType  # 37
    """기타기호 (논리수학기호,화폐기호)"""
    SL: Morpheme.Tag.ValueType  # 32
    """외국어"""
    SH: Morpheme.Tag.ValueType  # 31
    """한자"""
    SN: Morpheme.Tag.ValueType  # 33
    """숫자"""

    TEXT_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    PROBABILITY_FIELD_NUMBER: builtins.int
    OUT_OF_VOCAB_FIELD_NUMBER: builtins.int
    CUSTOM_DICT_NAME_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> bareun.lang_common_pb2.TextSpan:
        """The sentence text."""
    tag: global___Morpheme.Tag.ValueType
    """형태소 태그"""
    probability: builtins.float
    """형태소 분석 결과 확률"""
    out_of_vocab: global___Morpheme.OutOfVocab.ValueType
    """유의어 번호
    int32 disambiguation = 4;

    사전에 없는 단어 표시
    """
    custom_dict_name: builtins.str
    """사용된 사용자 사전의 이름"""
    def __init__(
        self,
        *,
        text: bareun.lang_common_pb2.TextSpan | None = ...,
        tag: global___Morpheme.Tag.ValueType = ...,
        probability: builtins.float = ...,
        out_of_vocab: global___Morpheme.OutOfVocab.ValueType = ...,
        custom_dict_name: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_custom_dict_name", b"_custom_dict_name", "custom_dict_name", b"custom_dict_name", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_custom_dict_name", b"_custom_dict_name", "custom_dict_name", b"custom_dict_name", "out_of_vocab", b"out_of_vocab", "probability", b"probability", "tag", b"tag", "text", b"text"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_custom_dict_name", b"_custom_dict_name"]) -> typing_extensions.Literal["custom_dict_name"] | None: ...

global___Morpheme = Morpheme

class Token(google.protobuf.message.Message):
    """어절"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    MORPHEMES_FIELD_NUMBER: builtins.int
    LEMMA_FIELD_NUMBER: builtins.int
    TAGGED_FIELD_NUMBER: builtins.int
    MODIFIED_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> bareun.lang_common_pb2.TextSpan:
        """The token text."""
    @property
    def morphemes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Morpheme]:
        """어절 내부의 형태소 분리"""
    lemma: builtins.str
    """원형
    [Lemma](https://en.wikipedia.org/wiki/Lemma_%28morphology%29) of the token.
    """
    tagged: builtins.str
    """테그 문자열"""
    modified: builtins.str
    """원래의 값과 다른 내용이 있으면 modified에 값을 넣는다."""
    def __init__(
        self,
        *,
        text: bareun.lang_common_pb2.TextSpan | None = ...,
        morphemes: collections.abc.Iterable[global___Morpheme] | None = ...,
        lemma: builtins.str = ...,
        tagged: builtins.str = ...,
        modified: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lemma", b"lemma", "modified", b"modified", "morphemes", b"morphemes", "tagged", b"tagged", "text", b"text"]) -> None: ...

global___Token = Token

class AnalyzeSyntaxRequest(google.protobuf.message.Message):
    """형태소 분석 요청 메시지"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCUMENT_FIELD_NUMBER: builtins.int
    ENCODING_TYPE_FIELD_NUMBER: builtins.int
    AUTO_SPLIT_SENTENCE_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAIN_FIELD_NUMBER: builtins.int
    AUTO_SPACING_FIELD_NUMBER: builtins.int
    AUTO_JOINTING_FIELD_NUMBER: builtins.int
    CUSTOM_DICT_NAMES_FIELD_NUMBER: builtins.int
    @property
    def document(self) -> bareun.lang_common_pb2.Document:
        """입력 문서"""
    encoding_type: bareun.lang_common_pb2.EncodingType.ValueType
    """오프셋을 계산하기 위한 인코딩 타입"""
    auto_split_sentence: builtins.bool
    """auto split sentence true이면 자동으로 문장 분리를 시도한다.
    없으면 NEWLINE을 기준으로 문장을 자른다.
    기본값은 false 이다.
    """
    custom_domain: builtins.str
    """커스텀 사전 도메인 정보
    v4.0에서는 폐기될 예정입니다. 새로운 custom_dict_names를 사용해주세요.
    새로운 custom_dict_names에 값이 들어있는 경우, 이 값은 무시됩니다.
    """
    auto_spacing: builtins.bool
    """자동 띄어쓰기"""
    auto_jointing: builtins.bool
    """자동 붙여쓰기"""
    @property
    def custom_dict_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """커스텀 사전 이름들
        CustomDictionaryService를 사용해서 만든 사전을 여러 개 지정한다.
        하나 이상의 지정할 경우, 먼저 나오는 사전이 우선되어 사용된다.
        """
    def __init__(
        self,
        *,
        document: bareun.lang_common_pb2.Document | None = ...,
        encoding_type: bareun.lang_common_pb2.EncodingType.ValueType = ...,
        auto_split_sentence: builtins.bool = ...,
        custom_domain: builtins.str = ...,
        auto_spacing: builtins.bool = ...,
        auto_jointing: builtins.bool = ...,
        custom_dict_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["document", b"document"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_jointing", b"auto_jointing", "auto_spacing", b"auto_spacing", "auto_split_sentence", b"auto_split_sentence", "custom_dict_names", b"custom_dict_names", "custom_domain", b"custom_domain", "document", b"document", "encoding_type", b"encoding_type"]) -> None: ...

global___AnalyzeSyntaxRequest = AnalyzeSyntaxRequest

class AnalyzeSyntaxResponse(google.protobuf.message.Message):
    """형태 분석 응답 메시지"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENTENCES_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    @property
    def sentences(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Sentence]:
        """입력된 문장에 포함된 문장들"""
    language: builtins.str
    """텍스트의 언어, 만일 언어가 지정되지 않은 경우에는 자동으로 탐지하여 반환한다.
    언어가 지정된 경우에는 동일한 언어를 반환한다.
    이때, 언어는 ko_KR 등과 같이 사용한다.
    """
    def __init__(
        self,
        *,
        sentences: collections.abc.Iterable[global___Sentence] | None = ...,
        language: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["language", b"language", "sentences", b"sentences"]) -> None: ...

global___AnalyzeSyntaxResponse = AnalyzeSyntaxResponse

class AnalyzeSyntaxListRequest(google.protobuf.message.Message):
    """형태소 분석 요청 메시지"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENTENCES_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    ENCODING_TYPE_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAIN_FIELD_NUMBER: builtins.int
    AUTO_SPACING_FIELD_NUMBER: builtins.int
    AUTO_JOINTING_FIELD_NUMBER: builtins.int
    CUSTOM_DICT_NAMES_FIELD_NUMBER: builtins.int
    @property
    def sentences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """입력 문장의 배열"""
    language: builtins.str
    """입력 문장의 언어"""
    encoding_type: bareun.lang_common_pb2.EncodingType.ValueType
    """오프셋을 계산하기 위한 인코딩 타입"""
    custom_domain: builtins.str
    """커스텀 사전 도메인 정보
    v4.0에서는 폐기될 예정입니다. 새로운 custom_dict_names를 사용해주세요.
    새로운 custom_dict_names에 값이 들어있는 경우, 이 값은 무시됩니다.
    """
    auto_spacing: builtins.bool
    """자동 띄어쓰기"""
    auto_jointing: builtins.bool
    """자동 붙여쓰기"""
    @property
    def custom_dict_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """커스텀 사전 이름들
        CustomDictionaryService를 사용해서 만든 사전을 여러 개 지정한다.
        하나 이상의 지정할 경우, 먼저 나오는 사전이 우선되어 사용된다.
        """
    def __init__(
        self,
        *,
        sentences: collections.abc.Iterable[builtins.str] | None = ...,
        language: builtins.str = ...,
        encoding_type: bareun.lang_common_pb2.EncodingType.ValueType = ...,
        custom_domain: builtins.str = ...,
        auto_spacing: builtins.bool = ...,
        auto_jointing: builtins.bool = ...,
        custom_dict_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_jointing", b"auto_jointing", "auto_spacing", b"auto_spacing", "custom_dict_names", b"custom_dict_names", "custom_domain", b"custom_domain", "encoding_type", b"encoding_type", "language", b"language", "sentences", b"sentences"]) -> None: ...

global___AnalyzeSyntaxListRequest = AnalyzeSyntaxListRequest

class AnalyzeSyntaxListResponse(google.protobuf.message.Message):
    """형태 분석 응답 메시지"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENTENCES_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    @property
    def sentences(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Sentence]:
        """입력된 문장에 포함된 문장들
        여기서 문장은 요청에 대응하여 1:1로 맞춰진다.
        만일 요청이 빈 문장이면 빈 문장으로 대응한다.
        """
    language: builtins.str
    """텍스트의 언어, 만일 언어가 지정되지 않은 경우에는 자동으로 탐지하여 반환한다.
    언어가 지정된 경우에는 동일한 언어를 반환한다.
    이때, 언어는 ko_KR 등과 같이 사용한다.
    """
    def __init__(
        self,
        *,
        sentences: collections.abc.Iterable[global___Sentence] | None = ...,
        language: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["language", b"language", "sentences", b"sentences"]) -> None: ...

global___AnalyzeSyntaxListResponse = AnalyzeSyntaxListResponse

class TokenizeRequest(google.protobuf.message.Message):
    """토크나이즈 요청 메시지"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCUMENT_FIELD_NUMBER: builtins.int
    ENCODING_TYPE_FIELD_NUMBER: builtins.int
    AUTO_SPLIT_SENTENCE_FIELD_NUMBER: builtins.int
    AUTO_SPACING_FIELD_NUMBER: builtins.int
    @property
    def document(self) -> bareun.lang_common_pb2.Document:
        """Input document."""
    encoding_type: bareun.lang_common_pb2.EncodingType.ValueType
    """The encoding type used by the API to calculate offsets."""
    auto_split_sentence: builtins.bool
    """auto split sentence true이면 자동으로 문장 분리를 시도한다.
    없으면 \\n 을 기준으로 문장을 자른다.
    기본값은 false 이다.
    """
    auto_spacing: builtins.bool
    """자동 띄어쓰기"""
    def __init__(
        self,
        *,
        document: bareun.lang_common_pb2.Document | None = ...,
        encoding_type: bareun.lang_common_pb2.EncodingType.ValueType = ...,
        auto_split_sentence: builtins.bool = ...,
        auto_spacing: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["document", b"document"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_spacing", b"auto_spacing", "auto_split_sentence", b"auto_split_sentence", "document", b"document", "encoding_type", b"encoding_type"]) -> None: ...

global___TokenizeRequest = TokenizeRequest

class Segment(google.protobuf.message.Message):
    """토큰의 분절된 내용"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    HINT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> bareun.lang_common_pb2.TextSpan:
        """The token text."""
    hint: builtins.str
    """각 위치에 대한 정보"""
    def __init__(
        self,
        *,
        text: bareun.lang_common_pb2.TextSpan | None = ...,
        hint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hint", b"hint", "text", b"text"]) -> None: ...

global___Segment = Segment

class SegmentToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    SEGMENTS_FIELD_NUMBER: builtins.int
    TAGGED_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> bareun.lang_common_pb2.TextSpan:
        """The token text."""
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Segment]:
        """어절 내부의 형태소 분리"""
    tagged: builtins.str
    """아름답/V+ㄴ/E"""
    def __init__(
        self,
        *,
        text: bareun.lang_common_pb2.TextSpan | None = ...,
        segments: collections.abc.Iterable[global___Segment] | None = ...,
        tagged: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["segments", b"segments", "tagged", b"tagged", "text", b"text"]) -> None: ...

global___SegmentToken = SegmentToken

class SegmentSentence(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TOKENS_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> bareun.lang_common_pb2.TextSpan:
        """The token text."""
    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SegmentToken]:
        """어절 내부의 형태소 분리"""
    def __init__(
        self,
        *,
        text: bareun.lang_common_pb2.TextSpan | None = ...,
        tokens: collections.abc.Iterable[global___SegmentToken] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "tokens", b"tokens"]) -> None: ...

global___SegmentSentence = SegmentSentence

class TokenizeResponse(google.protobuf.message.Message):
    """Tokenize 요청 토크나이즈에 대한 요청"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENTENCES_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    @property
    def sentences(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SegmentSentence]:
        """분절 분리된 문장들의 배열"""
    language: builtins.str
    """ISO 문자 코드"""
    def __init__(
        self,
        *,
        sentences: collections.abc.Iterable[global___SegmentSentence] | None = ...,
        language: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["language", b"language", "sentences", b"sentences"]) -> None: ...

global___TokenizeResponse = TokenizeResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bareun/lang_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62\x61reun/lang_common.proto\x12\x06\x62\x61reun\"A\n\x08TextSpan\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x65gin_offset\x18\x02 \x01(\x05\x12\x0e\n\x06length\x18\x03 \x01(\x05\"-\n\x08\x44ocument\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x04 \x01(\t*8\n\x0c\x45ncodingType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04UTF8\x10\x01\x12\t\n\x05UTF16\x10\x02\x12\t\n\x05UTF32\x10\x03\x42=\n\x10\x61i.bareun.protosB\x0fLangCommonProtoP\x01Z\x16\x62\x61reun.ai/proto/bareunb\x06proto3')

_ENCODINGTYPE = DESCRIPTOR.enum_types_by_name['EncodingType']
EncodingType = enum_type_wrapper.EnumTypeWrapper(_ENCODINGTYPE)
NONE = 0
UTF8 = 1
UTF16 = 2
UTF32 = 3


_TEXTSPAN = DESCRIPTOR.message_types_by_name['TextSpan']
_DOCUMENT = DESCRIPTOR.message_types_by_name['Document']
TextSpan = _reflection.GeneratedProtocolMessageType('TextSpan', (_message.Message,), {
  'DESCRIPTOR' : _TEXTSPAN,
  '__module__' : 'bareun.lang_common_pb2'
  # @@protoc_insertion_point(class_scope:bareun.TextSpan)
  })
_sym_db.RegisterMessage(TextSpan)

Document = _reflection.GeneratedProtocolMessageType('Document', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENT,
  '__module__' : 'bareun.lang_common_pb2'
  # @@protoc_insertion_point(class_scope:bareun.Document)
  })
_sym_db.RegisterMessage(Document)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020ai.bareun.protosB\017LangCommonProtoP\001Z\026bareun.ai/proto/bareun'
  _ENCODINGTYPE._serialized_start=150
  _ENCODINGTYPE._serialized_end=206
  _TEXTSPAN._serialized_start=36
  _TEXTSPAN._serialized_end=101
  _DOCUMENT._serialized_start=103
  _DOCUMENT._serialized_end=148
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2024-present BAIKAL AI Inc."""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _EncodingType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EncodingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EncodingType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NONE: _EncodingType.ValueType  # 0
    """If `EncodingType` is not specified, encoding-dependent information (such as
    `begin_offset`) will be set at `-1`.
    """
    UTF8: _EncodingType.ValueType  # 1
    """Encoding-dependent information (such as `begin_offset`) is calculated based
    on the UTF-8 encoding of the input. C++ and Go are examples of languages
    that use this encoding natively.
    """
    UTF16: _EncodingType.ValueType  # 2
    """Encoding-dependent information (such as `begin_offset`) is calculated based
    on the UTF-16 encoding of the input. Java and JavaScript are examples of
    languages that use this encoding natively.
    """
    UTF32: _EncodingType.ValueType  # 3
    """Encoding-dependent information (such as `begin_offset`) is calculated based
    on the UTF-32 encoding of the input. Python is an example of a language
    that uses this encoding natively.
    """

class EncodingType(_EncodingType, metaclass=_EncodingTypeEnumTypeWrapper):
    """Represents the text encoding that the caller uses to process the output.
    Providing an `EncodingType` is recommended because the API provides the
    beginning offsets for various outputs, such as tokens and mentions, and
    languages that natively use different text encodings may access offsets
    differently.
    """

NONE: EncodingType.ValueType  # 0
"""If `EncodingType` is not specified, encoding-dependent information (such as
`begin_offset`) will be set at `-1`.
"""
UTF8: EncodingType.ValueType  # 1
"""Encoding-dependent information (such as `begin_offset`) is calculated based
on the UTF-8 encoding of the input. C++ and Go are examples of languages
that use this encoding natively.
"""
UTF16: EncodingType.ValueType  # 2
"""Encoding-dependent information (such as `begin_offset`) is calculated based
on the UTF-16 encoding of the input. Java and JavaScript are examples of
languages that use this encoding natively.
"""
UTF32: EncodingType.ValueType  # 3
"""Encoding-dependent information (such as `begin_offset`) is calculated based
on the UTF-32 encoding of the input. Python is an example of a language
that uses this encoding natively.
"""
global___EncodingType = EncodingType

class TextSpan(google.protobuf.message.Message):
    """텍스트 조각"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    BEGIN_OFFSET_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    content: builtins.str
    """텍스트 조각의 내용"""
    begin_offset: builtins.int
    """텍스트 조각의 위치
    EncodingType에 따라서 위치의 값이 달라진다.
    """
    length: builtins.int
    """길이"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        begin_offset: builtins.int = ...,
        length: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_offset", b"begin_offset", "content", b"content", "length", b"length"]) -> None: ...

global___TextSpan = TextSpan

class Document(google.protobuf.message.Message):
    """
    Represents the input to API methods.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    content: builtins.str
    """입력 전체의 내용
    여러 문장이 입력되면 "\\n"을 넣어준다.
    """
    language: builtins.str
    """문서의 언어. 현재는 ko_KR 만 지원한다."""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        language: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "language", b"language"]) -> None: ...

global___Document = Document



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bareun/custom_dict.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bareun import dict_common_pb2 as bareun_dot_dict__common__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62\x61reun/custom_dict.proto\x12\x06\x62\x61reun\x1a\x18\x62\x61reun/dict_common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\"\x93\x03\n\x14\x43ustomDictionaryMeta\x12\x13\n\x0b\x64omain_name\x18\x01 \x01(\t\x12\x35\n\x06np_set\x18\x02 \x01(\x0b\x32%.bareun.CustomDictionaryMeta.DictMeta\x12\x35\n\x06\x63p_set\x18\x03 \x01(\x0b\x32%.bareun.CustomDictionaryMeta.DictMeta\x12;\n\x0c\x63p_caret_set\x18\x04 \x01(\x0b\x32%.bareun.CustomDictionaryMeta.DictMeta\x12\x35\n\x06vv_set\x18\x05 \x01(\x0b\x32%.bareun.CustomDictionaryMeta.DictMeta\x12\x35\n\x06va_set\x18\x06 \x01(\x0b\x32%.bareun.CustomDictionaryMeta.DictMeta\x1aM\n\x08\x44ictMeta\x12\x1e\n\x04type\x18\x01 \x01(\x0e\x32\x10.bareun.DictType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bitems_count\x18\x03 \x01(\x05\"\xb6\x02\n\x10\x43ustomDictionary\x12\x13\n\x0b\x64omain_name\x18\x01 \x01(\t\x12\x1f\n\x06np_set\x18\x02 \x01(\x0b\x32\x0f.bareun.DictSet\x12\x1f\n\x06\x63p_set\x18\x03 \x01(\x0b\x32\x0f.bareun.DictSet\x12%\n\x0c\x63p_caret_set\x18\x04 \x01(\x0b\x32\x0f.bareun.DictSet\x12\x1f\n\x06vv_set\x18\x05 \x01(\x0b\x32\x0f.bareun.DictSet\x12\x1f\n\x06va_set\x18\x06 \x01(\x0b\x32\x0f.bareun.DictSet\x12\x1f\n\x06mm_set\x18\x07 \x01(\x0b\x32\x0f.bareun.DictSet\x12 \n\x07mag_set\x18\x08 \x01(\x0b\x32\x0f.bareun.DictSet\x12\x1f\n\x06ic_set\x18\t \x01(\x0b\x32\x0f.bareun.DictSet\"\xae\x01\n\x13\x43ustomDictionaryMap\x12G\n\x0f\x63ustom_dict_map\x18\x01 \x03(\x0b\x32..bareun.CustomDictionaryMap.CustomDictMapEntry\x1aN\n\x12\x43ustomDictMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.bareun.CustomDictionary:\x02\x38\x01\"U\n\x1fGetCustomDictionaryListResponse\x12\x32\n\x0c\x64omain_dicts\x18\x01 \x03(\x0b\x32\x1c.bareun.CustomDictionaryMeta\"1\n\x1aGetCustomDictionaryRequest\x12\x13\n\x0b\x64omain_name\x18\x01 \x01(\t\"Z\n\x1bGetCustomDictionaryResponse\x12\x13\n\x0b\x64omain_name\x18\x01 \x01(\t\x12&\n\x04\x64ict\x18\x02 \x01(\x0b\x32\x18.bareun.CustomDictionary\"\\\n\x1dUpdateCustomDictionaryRequest\x12\x13\n\x0b\x64omain_name\x18\x01 \x01(\t\x12&\n\x04\x64ict\x18\x02 \x01(\x0b\x32\x18.bareun.CustomDictionary\"=\n\x1eUpdateCustomDictionaryResponse\x12\x1b\n\x13updated_domain_name\x18\x01 \x01(\t\"D\n\x1fRemoveCustomDictionariesRequest\x12\x14\n\x0c\x64omain_names\x18\x01 \x03(\t\x12\x0b\n\x03\x61ll\x18\x02 \x01(\x08\"\xbd\x01\n RemoveCustomDictionariesResponse\x12^\n\x14\x64\x65leted_domain_names\x18\x01 \x03(\x0b\x32@.bareun.RemoveCustomDictionariesResponse.DeletedDomainNamesEntry\x1a\x39\n\x17\x44\x65letedDomainNamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\",\n\x14\x43heckConflictRequest\x12\x14\n\x0c\x64omain_names\x18\x01 \x03(\t\"<\n\x15\x43heckConflictResponse\x12#\n\tconflicts\x18\x01 \x03(\x0b\x32\x10.bareun.Conflict\"3\n\x07\x44ictOne\x12\x11\n\tdict_name\x18\x01 \x01(\t\x12\x15\n\rdict_set_name\x18\x02 \x01(\t\"\xac\x01\n\x08\x43onflict\x12\x1d\n\x04left\x18\x01 \x01(\x0b\x32\x0f.bareun.DictOne\x12\x1e\n\x05right\x18\x02 \x01(\x0b\x32\x0f.bareun.DictOne\x12\x11\n\tleft_word\x18\x03 \x01(\t\x12\x12\n\nright_word\x18\x04 \x01(\t\x12\x10\n\x08\x63onflict\x18\x05 \x01(\x08\x12\x12\n\nduplicated\x18\x06 \x01(\x08\x12\x14\n\x0c\x63onflict_msg\x18\x0b \x01(\t2\xf0\x05\n\x17\x43ustomDictionaryService\x12\x80\x01\n\x17GetCustomDictionaryList\x12\x16.google.protobuf.Empty\x1a\'.bareun.GetCustomDictionaryListResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x19/bareun/api/v1/customdict:\x01*\x12\x92\x01\n\x13GetCustomDictionary\x12\".bareun.GetCustomDictionaryRequest\x1a#.bareun.GetCustomDictionaryResponse\"2\x82\xd3\xe4\x93\x02,\x12\'/bareun/api/v1/customdict/{domain_name}:\x01*\x12\x9b\x01\n\x16UpdateCustomDictionary\x12%.bareun.UpdateCustomDictionaryRequest\x1a&.bareun.UpdateCustomDictionaryResponse\"2\x82\xd3\xe4\x93\x02,\"\'/bareun/api/v1/customdict/{domain_name}:\x01*\x12\x9a\x01\n\x18RemoveCustomDictionaries\x12\'.bareun.RemoveCustomDictionariesRequest\x1a(.bareun.RemoveCustomDictionariesResponse\"+\x82\xd3\xe4\x93\x02%\" /bareun/api/v1/customdict/delete:\x01*\x12\x81\x01\n\rCheckConflict\x12\x1c.bareun.CheckConflictRequest\x1a\x1d.bareun.CheckConflictResponse\"3\x82\xd3\xe4\x93\x02-\"(/bareun/api/v1/customdict/check-conflict:\x01*BJ\n\x10\x61i.bareun.protosB\x1c\x43ustomDictionaryServiceProtoP\x01Z\x16\x62\x61reun.ai/proto/bareunb\x06proto3')



_CUSTOMDICTIONARYMETA = DESCRIPTOR.message_types_by_name['CustomDictionaryMeta']
_CUSTOMDICTIONARYMETA_DICTMETA = _CUSTOMDICTIONARYMETA.nested_types_by_name['DictMeta']
_CUSTOMDICTIONARY = DESCRIPTOR.message_types_by_name['CustomDictionary']
_CUSTOMDICTIONARYMAP = DESCRIPTOR.message_types_by_name['CustomDictionaryMap']
_CUSTOMDICTIONARYMAP_CUSTOMDICTMAPENTRY = _CUSTOMDICTIONARYMAP.nested_types_by_name['CustomDictMapEntry']
_GETCUSTOMDICTIONARYLISTRESPONSE = DESCRIPTOR.message_types_by_name['GetCustomDictionaryListResponse']
_GETCUSTOMDICTIONARYREQUEST = DESCRIPTOR.message_types_by_name['GetCustomDictionaryRequest']
_GETCUSTOMDICTIONARYRESPONSE = DESCRIPTOR.message_types_by_name['GetCustomDictionaryResponse']
_UPDATECUSTOMDICTIONARYREQUEST = DESCRIPTOR.message_types_by_name['UpdateCustomDictionaryRequest']
_UPDATECUSTOMDICTIONARYRESPONSE = DESCRIPTOR.message_types_by_name['UpdateCustomDictionaryResponse']
_REMOVECUSTOMDICTIONARIESREQUEST = DESCRIPTOR.message_types_by_name['RemoveCustomDictionariesRequest']
_REMOVECUSTOMDICTIONARIESRESPONSE = DESCRIPTOR.message_types_by_name['RemoveCustomDictionariesResponse']
_REMOVECUSTOMDICTIONARIESRESPONSE_DELETEDDOMAINNAMESENTRY = _REMOVECUSTOMDICTIONARIESRESPONSE.nested_types_by_name['DeletedDomainNamesEntry']
_CHECKCONFLICTREQUEST = DESCRIPTOR.message_types_by_name['CheckConflictRequest']
_CHECKCONFLICTRESPONSE = DESCRIPTOR.message_types_by_name['CheckConflictResponse']
_DICTONE = DESCRIPTOR.message_types_by_name['DictOne']
_CONFLICT = DESCRIPTOR.message_types_by_name['Conflict']
CustomDictionaryMeta = _reflection.GeneratedProtocolMessageType('CustomDictionaryMeta', (_message.Message,), {

  'DictMeta' : _reflection.GeneratedProtocolMessageType('DictMeta', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMDICTIONARYMETA_DICTMETA,
    '__module__' : 'bareun.custom_dict_pb2'
    # @@protoc_insertion_point(class_scope:bareun.CustomDictionaryMeta.DictMeta)
    })
  ,
  'DESCRIPTOR' : _CUSTOMDICTIONARYMETA,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.CustomDictionaryMeta)
  })
_sym_db.RegisterMessage(CustomDictionaryMeta)
_sym_db.RegisterMessage(CustomDictionaryMeta.DictMeta)

CustomDictionary = _reflection.GeneratedProtocolMessageType('CustomDictionary', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMDICTIONARY,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.CustomDictionary)
  })
_sym_db.RegisterMessage(CustomDictionary)

CustomDictionaryMap = _reflection.GeneratedProtocolMessageType('CustomDictionaryMap', (_message.Message,), {

  'CustomDictMapEntry' : _reflection.GeneratedProtocolMessageType('CustomDictMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMDICTIONARYMAP_CUSTOMDICTMAPENTRY,
    '__module__' : 'bareun.custom_dict_pb2'
    # @@protoc_insertion_point(class_scope:bareun.CustomDictionaryMap.CustomDictMapEntry)
    })
  ,
  'DESCRIPTOR' : _CUSTOMDICTIONARYMAP,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.CustomDictionaryMap)
  })
_sym_db.RegisterMessage(CustomDictionaryMap)
_sym_db.RegisterMessage(CustomDictionaryMap.CustomDictMapEntry)

GetCustomDictionaryListResponse = _reflection.GeneratedProtocolMessageType('GetCustomDictionaryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCUSTOMDICTIONARYLISTRESPONSE,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.GetCustomDictionaryListResponse)
  })
_sym_db.RegisterMessage(GetCustomDictionaryListResponse)

GetCustomDictionaryRequest = _reflection.GeneratedProtocolMessageType('GetCustomDictionaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCUSTOMDICTIONARYREQUEST,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.GetCustomDictionaryRequest)
  })
_sym_db.RegisterMessage(GetCustomDictionaryRequest)

GetCustomDictionaryResponse = _reflection.GeneratedProtocolMessageType('GetCustomDictionaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCUSTOMDICTIONARYRESPONSE,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.GetCustomDictionaryResponse)
  })
_sym_db.RegisterMessage(GetCustomDictionaryResponse)

UpdateCustomDictionaryRequest = _reflection.GeneratedProtocolMessageType('UpdateCustomDictionaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECUSTOMDICTIONARYREQUEST,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.UpdateCustomDictionaryRequest)
  })
_sym_db.RegisterMessage(UpdateCustomDictionaryRequest)

UpdateCustomDictionaryResponse = _reflection.GeneratedProtocolMessageType('UpdateCustomDictionaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECUSTOMDICTIONARYRESPONSE,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.UpdateCustomDictionaryResponse)
  })
_sym_db.RegisterMessage(UpdateCustomDictionaryResponse)

RemoveCustomDictionariesRequest = _reflection.GeneratedProtocolMessageType('RemoveCustomDictionariesRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECUSTOMDICTIONARIESREQUEST,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.RemoveCustomDictionariesRequest)
  })
_sym_db.RegisterMessage(RemoveCustomDictionariesRequest)

RemoveCustomDictionariesResponse = _reflection.GeneratedProtocolMessageType('RemoveCustomDictionariesResponse', (_message.Message,), {

  'DeletedDomainNamesEntry' : _reflection.GeneratedProtocolMessageType('DeletedDomainNamesEntry', (_message.Message,), {
    'DESCRIPTOR' : _REMOVECUSTOMDICTIONARIESRESPONSE_DELETEDDOMAINNAMESENTRY,
    '__module__' : 'bareun.custom_dict_pb2'
    # @@protoc_insertion_point(class_scope:bareun.RemoveCustomDictionariesResponse.DeletedDomainNamesEntry)
    })
  ,
  'DESCRIPTOR' : _REMOVECUSTOMDICTIONARIESRESPONSE,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.RemoveCustomDictionariesResponse)
  })
_sym_db.RegisterMessage(RemoveCustomDictionariesResponse)
_sym_db.RegisterMessage(RemoveCustomDictionariesResponse.DeletedDomainNamesEntry)

CheckConflictRequest = _reflection.GeneratedProtocolMessageType('CheckConflictRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKCONFLICTREQUEST,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.CheckConflictRequest)
  })
_sym_db.RegisterMessage(CheckConflictRequest)

CheckConflictResponse = _reflection.GeneratedProtocolMessageType('CheckConflictResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKCONFLICTRESPONSE,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.CheckConflictResponse)
  })
_sym_db.RegisterMessage(CheckConflictResponse)

DictOne = _reflection.GeneratedProtocolMessageType('DictOne', (_message.Message,), {
  'DESCRIPTOR' : _DICTONE,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.DictOne)
  })
_sym_db.RegisterMessage(DictOne)

Conflict = _reflection.GeneratedProtocolMessageType('Conflict', (_message.Message,), {
  'DESCRIPTOR' : _CONFLICT,
  '__module__' : 'bareun.custom_dict_pb2'
  # @@protoc_insertion_point(class_scope:bareun.Conflict)
  })
_sym_db.RegisterMessage(Conflict)

_CUSTOMDICTIONARYSERVICE = DESCRIPTOR.services_by_name['CustomDictionaryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020ai.bareun.protosB\034CustomDictionaryServiceProtoP\001Z\026bareun.ai/proto/bareun'
  _CUSTOMDICTIONARYMAP_CUSTOMDICTMAPENTRY._options = None
  _CUSTOMDICTIONARYMAP_CUSTOMDICTMAPENTRY._serialized_options = b'8\001'
  _REMOVECUSTOMDICTIONARIESRESPONSE_DELETEDDOMAINNAMESENTRY._options = None
  _REMOVECUSTOMDICTIONARIESRESPONSE_DELETEDDOMAINNAMESENTRY._serialized_options = b'8\001'
  _CUSTOMDICTIONARYSERVICE.methods_by_name['GetCustomDictionaryList']._options = None
  _CUSTOMDICTIONARYSERVICE.methods_by_name['GetCustomDictionaryList']._serialized_options = b'\202\323\344\223\002\036\022\031/bareun/api/v1/customdict:\001*'
  _CUSTOMDICTIONARYSERVICE.methods_by_name['GetCustomDictionary']._options = None
  _CUSTOMDICTIONARYSERVICE.methods_by_name['GetCustomDictionary']._serialized_options = b'\202\323\344\223\002,\022\'/bareun/api/v1/customdict/{domain_name}:\001*'
  _CUSTOMDICTIONARYSERVICE.methods_by_name['UpdateCustomDictionary']._options = None
  _CUSTOMDICTIONARYSERVICE.methods_by_name['UpdateCustomDictionary']._serialized_options = b'\202\323\344\223\002,\"\'/bareun/api/v1/customdict/{domain_name}:\001*'
  _CUSTOMDICTIONARYSERVICE.methods_by_name['RemoveCustomDictionaries']._options = None
  _CUSTOMDICTIONARYSERVICE.methods_by_name['RemoveCustomDictionaries']._serialized_options = b'\202\323\344\223\002%\" /bareun/api/v1/customdict/delete:\001*'
  _CUSTOMDICTIONARYSERVICE.methods_by_name['CheckConflict']._options = None
  _CUSTOMDICTIONARYSERVICE.methods_by_name['CheckConflict']._serialized_options = b'\202\323\344\223\002-\"(/bareun/api/v1/customdict/check-conflict:\001*'
  _CUSTOMDICTIONARYMETA._serialized_start=122
  _CUSTOMDICTIONARYMETA._serialized_end=525
  _CUSTOMDICTIONARYMETA_DICTMETA._serialized_start=448
  _CUSTOMDICTIONARYMETA_DICTMETA._serialized_end=525
  _CUSTOMDICTIONARY._serialized_start=528
  _CUSTOMDICTIONARY._serialized_end=838
  _CUSTOMDICTIONARYMAP._serialized_start=841
  _CUSTOMDICTIONARYMAP._serialized_end=1015
  _CUSTOMDICTIONARYMAP_CUSTOMDICTMAPENTRY._serialized_start=937
  _CUSTOMDICTIONARYMAP_CUSTOMDICTMAPENTRY._serialized_end=1015
  _GETCUSTOMDICTIONARYLISTRESPONSE._serialized_start=1017
  _GETCUSTOMDICTIONARYLISTRESPONSE._serialized_end=1102
  _GETCUSTOMDICTIONARYREQUEST._serialized_start=1104
  _GETCUSTOMDICTIONARYREQUEST._serialized_end=1153
  _GETCUSTOMDICTIONARYRESPONSE._serialized_start=1155
  _GETCUSTOMDICTIONARYRESPONSE._serialized_end=1245
  _UPDATECUSTOMDICTIONARYREQUEST._serialized_start=1247
  _UPDATECUSTOMDICTIONARYREQUEST._serialized_end=1339
  _UPDATECUSTOMDICTIONARYRESPONSE._serialized_start=1341
  _UPDATECUSTOMDICTIONARYRESPONSE._serialized_end=1402
  _REMOVECUSTOMDICTIONARIESREQUEST._serialized_start=1404
  _REMOVECUSTOMDICTIONARIESREQUEST._serialized_end=1472
  _REMOVECUSTOMDICTIONARIESRESPONSE._serialized_start=1475
  _REMOVECUSTOMDICTIONARIESRESPONSE._serialized_end=1664
  _REMOVECUSTOMDICTIONARIESRESPONSE_DELETEDDOMAINNAMESENTRY._serialized_start=1607
  _REMOVECUSTOMDICTIONARIESRESPONSE_DELETEDDOMAINNAMESENTRY._serialized_end=1664
  _CHECKCONFLICTREQUEST._serialized_start=1666
  _CHECKCONFLICTREQUEST._serialized_end=1710
  _CHECKCONFLICTRESPONSE._serialized_start=1712
  _CHECKCONFLICTRESPONSE._serialized_end=1772
  _DICTONE._serialized_start=1774
  _DICTONE._serialized_end=1825
  _CONFLICT._serialized_start=1828
  _CONFLICT._serialized_end=2000
  _CUSTOMDICTIONARYSERVICE._serialized_start=2003
  _CUSTOMDICTIONARYSERVICE._serialized_end=2755
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bareun/revision_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from bareun import lang_common_pb2 as bareun_dot_lang__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x62\x61reun/revision_service.proto\x12\x06\x62\x61reun\x1a\x1cgoogle/api/annotations.proto\x1a\x18\x62\x61reun/lang_common.proto\"\xad\x01\n\x0eRevisionConfig\x12\x1e\n\x16\x64isable_split_sentence\x18\x01 \x01(\x08\x12\x1d\n\x15\x64isable_caret_spacing\x18\x02 \x01(\x08\x12\x1a\n\x12\x64isable_vx_spacing\x18\x03 \x01(\x08\x12!\n\x19\x65nable_cleanup_whitespace\x18\x0b \x01(\x08\x12\x1d\n\x15\x65nable_sentence_check\x18\x15 \x01(\x08\"\xc4\x01\n\x13\x43orrectErrorRequest\x12\"\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x10.bareun.Document\x12+\n\rencoding_type\x18\x02 \x01(\x0e\x32\x14.bareun.EncodingType\x12\x19\n\rcustom_domain\x18\x04 \x01(\tB\x02\x18\x01\x12\x19\n\x11\x63ustom_dict_names\x18\x05 \x03(\t\x12&\n\x06\x63onfig\x18\x0b \x01(\x0b\x32\x16.bareun.RevisionConfig\"}\n\nReviseHelp\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x08\x63\x61tegory\x18\x02 \x01(\x0e\x32\x18.bareun.RevisionCategory\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x10\n\x08\x65xamples\x18\x04 \x03(\t\x12\x14\n\x0crule_article\x18\x05 \x01(\t\"g\n\x08Revision\x12\x0f\n\x07revised\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x01\x12*\n\x08\x63\x61tegory\x18\x03 \x01(\x0e\x32\x18.bareun.RevisionCategory\x12\x0f\n\x07help_id\x18\x04 \x01(\t\"\xbf\x01\n\x0cRevisedBlock\x12 \n\x06origin\x18\x01 \x01(\x0b\x32\x10.bareun.TextSpan\x12\x0f\n\x07revised\x18\x02 \x01(\t\x12#\n\trevisions\x18\x03 \x03(\x0b\x32\x10.bareun.Revision\x12$\n\x06nested\x18\n \x03(\x0b\x32\x14.bareun.RevisedBlock\x12\r\n\x05lemma\x18\x04 \x01(\t\x12\"\n\x03pos\x18\x05 \x01(\x0e\x32\x15.bareun.CustomDictPos\"2\n\x0fRevisedSentence\x12\x0e\n\x06origin\x18\x01 \x01(\t\x12\x0f\n\x07revised\x18\x02 \x01(\t\"\x99\x01\n\x0c\x43leanUpRange\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x05\x12\x36\n\x08position\x18\x03 \x01(\x0e\x32$.bareun.CleanUpRange.CleanUpPosition\"1\n\x0f\x43leanUpPosition\x12\t\n\x05START\x10\x00\x12\x07\n\x03\x45ND\x10\x01\x12\n\n\x06MIDDLE\x10\x02\"\xde\x02\n\x14\x43orrectErrorResponse\x12\x0e\n\x06origin\x18\x01 \x01(\t\x12\x0f\n\x07revised\x18\x02 \x01(\t\x12,\n\x0erevised_blocks\x18\x03 \x03(\x0b\x32\x14.bareun.RevisedBlock\x12\x37\n\x19whitespace_cleanup_ranges\x18\t \x03(\x0b\x32\x14.bareun.CleanUpRange\x12\x32\n\x11revised_sentences\x18\x0b \x03(\x0b\x32\x17.bareun.RevisedSentence\x12\x36\n\x05helps\x18\x0c \x03(\x0b\x32\'.bareun.CorrectErrorResponse.HelpsEntry\x12\x10\n\x08language\x18\x63 \x01(\t\x1a@\n\nHelpsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.bareun.ReviseHelp:\x02\x38\x01*\x9e\x01\n\x10RevisionCategory\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07GRAMMER\x10\x01\x12\x08\n\x04WORD\x10\x02\x12\x0b\n\x07SPACING\x10\x03\x12\x0c\n\x08STANDARD\x10\x08\x12\x08\n\x04TYPO\x10\t\x12\x10\n\x0c\x46OREIGN_WORD\x10\n\x12\x14\n\x10\x43ONFUSABLE_WORDS\x10\x0b\x12\x0c\n\x08SENTENCE\x10\x0c\x12\x0b\n\x07\x43ONFIRM\x10\r*\x86\x01\n\rCustomDictPos\x12\x0b\n\x07POS_UNK\x10\x00\x12\x0b\n\x07POS_NNG\x10\x01\x12\x0b\n\x07POS_NNP\x10\x02\x12\x11\n\rPOS_NNG_CARET\x10\x03\x12\n\n\x06POS_VV\x10\x04\x12\n\n\x06POS_VA\x10\x05\x12\n\n\x06POS_MM\x10\x06\x12\x0b\n\x07POS_MAG\x10\x07\x12\n\n\x06POS_IC\x10\x08\x32\x85\x01\n\x0fRevisionService\x12r\n\x0c\x43orrectError\x12\x1b.bareun.CorrectErrorRequest\x1a\x1c.bareun.CorrectErrorResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/bareun/api/v1/correct-error:\x01*BB\n\x10\x61i.bareun.protosB\x14RevisionServiceProtoP\x01Z\x16\x62\x61reun.ai/proto/bareunb\x06proto3')

_REVISIONCATEGORY = DESCRIPTOR.enum_types_by_name['RevisionCategory']
RevisionCategory = enum_type_wrapper.EnumTypeWrapper(_REVISIONCATEGORY)
_CUSTOMDICTPOS = DESCRIPTOR.enum_types_by_name['CustomDictPos']
CustomDictPos = enum_type_wrapper.EnumTypeWrapper(_CUSTOMDICTPOS)
UNKNOWN = 0
GRAMMER = 1
WORD = 2
SPACING = 3
STANDARD = 8
TYPO = 9
FOREIGN_WORD = 10
CONFUSABLE_WORDS = 11
SENTENCE = 12
CONFIRM = 13
POS_UNK = 0
POS_NNG = 1
POS_NNP = 2
POS_NNG_CARET = 3
POS_VV = 4
POS_VA = 5
POS_MM = 6
POS_MAG = 7
POS_IC = 8


_REVISIONCONFIG = DESCRIPTOR.message_types_by_name['RevisionConfig']
_CORRECTERRORREQUEST = DESCRIPTOR.message_types_by_name['CorrectErrorRequest']
_REVISEHELP = DESCRIPTOR.message_types_by_name['ReviseHelp']
_REVISION = DESCRIPTOR.message_types_by_name['Revision']
_REVISEDBLOCK = DESCRIPTOR.message_types_by_name['RevisedBlock']
_REVISEDSENTENCE = DESCRIPTOR.message_types_by_name['RevisedSentence']
_CLEANUPRANGE = DESCRIPTOR.message_types_by_name['CleanUpRange']
_CORRECTERRORRESPONSE = DESCRIPTOR.message_types_by_name['CorrectErrorResponse']
_CORRECTERRORRESPONSE_HELPSENTRY = _CORRECTERRORRESPONSE.nested_types_by_name['HelpsEntry']
_CLEANUPRANGE_CLEANUPPOSITION = _CLEANUPRANGE.enum_types_by_name['CleanUpPosition']
RevisionConfig = _reflection.GeneratedProtocolMessageType('RevisionConfig', (_message.Message,), {
  'DESCRIPTOR' : _REVISIONCONFIG,
  '__module__' : 'bareun.revision_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.RevisionConfig)
  })
_sym_db.RegisterMessage(RevisionConfig)

CorrectErrorRequest = _reflection.GeneratedProtocolMessageType('CorrectErrorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CORRECTERRORREQUEST,
  '__module__' : 'bareun.revision_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.CorrectErrorRequest)
  })
_sym_db.RegisterMessage(CorrectErrorRequest)

ReviseHelp = _reflection.GeneratedProtocolMessageType('ReviseHelp', (_message.Message,), {
  'DESCRIPTOR' : _REVISEHELP,
  '__module__' : 'bareun.revision_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.ReviseHelp)
  })
_sym_db.RegisterMessage(ReviseHelp)

Revision = _reflection.GeneratedProtocolMessageType('Revision', (_message.Message,), {
  'DESCRIPTOR' : _REVISION,
  '__module__' : 'bareun.revision_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.Revision)
  })
_sym_db.RegisterMessage(Revision)

RevisedBlock = _reflection.GeneratedProtocolMessageType('RevisedBlock', (_message.Message,), {
  'DESCRIPTOR' : _REVISEDBLOCK,
  '__module__' : 'bareun.revision_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.RevisedBlock)
  })
_sym_db.RegisterMessage(RevisedBlock)

RevisedSentence = _reflection.GeneratedProtocolMessageType('RevisedSentence', (_message.Message,), {
  'DESCRIPTOR' : _REVISEDSENTENCE,
  '__module__' : 'bareun.revision_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.RevisedSentence)
  })
_sym_db.RegisterMessage(RevisedSentence)

CleanUpRange = _reflection.GeneratedProtocolMessageType('CleanUpRange', (_message.Message,), {
  'DESCRIPTOR' : _CLEANUPRANGE,
  '__module__' : 'bareun.revision_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.CleanUpRange)
  })
_sym_db.RegisterMessage(CleanUpRange)

CorrectErrorResponse = _reflection.GeneratedProtocolMessageType('CorrectErrorResponse', (_message.Message,), {

  'HelpsEntry' : _reflection.GeneratedProtocolMessageType('HelpsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CORRECTERRORRESPONSE_HELPSENTRY,
    '__module__' : 'bareun.revision_service_pb2'
    # @@protoc_insertion_point(class_scope:bareun.CorrectErrorResponse.HelpsEntry)
    })
  ,
  'DESCRIPTOR' : _CORRECTERRORRESPONSE,
  '__module__' : 'bareun.revision_service_pb2'
  # @@protoc_insertion_point(class_scope:bareun.CorrectErrorResponse)
  })
_sym_db.RegisterMessage(CorrectErrorResponse)
_sym_db.RegisterMessage(CorrectErrorResponse.HelpsEntry)

_REVISIONSERVICE = DESCRIPTOR.services_by_name['RevisionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020ai.bareun.protosB\024RevisionServiceProtoP\001Z\026bareun.ai/proto/bareun'
  _CORRECTERRORREQUEST.fields_by_name['custom_domain']._options = None
  _CORRECTERRORREQUEST.fields_by_name['custom_domain']._serialized_options = b'\030\001'
  _CORRECTERRORRESPONSE_HELPSENTRY._options = None
  _CORRECTERRORRESPONSE_HELPSENTRY._serialized_options = b'8\001'
  _REVISIONSERVICE.methods_by_name['CorrectError']._options = None
  _REVISIONSERVICE.methods_by_name['CorrectError']._serialized_options = b'\202\323\344\223\002!\"\034/bareun/api/v1/correct-error:\001*'
  _REVISIONCATEGORY._serialized_start=1460
  _REVISIONCATEGORY._serialized_end=1618
  _CUSTOMDICTPOS._serialized_start=1621
  _CUSTOMDICTPOS._serialized_end=1755
  _REVISIONCONFIG._serialized_start=98
  _REVISIONCONFIG._serialized_end=271
  _CORRECTERRORREQUEST._serialized_start=274
  _CORRECTERRORREQUEST._serialized_end=470
  _REVISEHELP._serialized_start=472
  _REVISEHELP._serialized_end=597
  _REVISION._serialized_start=599
  _REVISION._serialized_end=702
  _REVISEDBLOCK._serialized_start=705
  _REVISEDBLOCK._serialized_end=896
  _REVISEDSENTENCE._serialized_start=898
  _REVISEDSENTENCE._serialized_end=948
  _CLEANUPRANGE._serialized_start=951
  _CLEANUPRANGE._serialized_end=1104
  _CLEANUPRANGE_CLEANUPPOSITION._serialized_start=1055
  _CLEANUPRANGE_CLEANUPPOSITION._serialized_end=1104
  _CORRECTERRORRESPONSE._serialized_start=1107
  _CORRECTERRORRESPONSE._serialized_end=1457
  _CORRECTERRORRESPONSE_HELPSENTRY._serialized_start=1393
  _CORRECTERRORRESPONSE_HELPSENTRY._serialized_end=1457
  _REVISIONSERVICE._serialized_start=1758
  _REVISIONSERVICE._serialized_end=1891
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bareun/dict_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62\x61reun/dict_common.proto\x12\x06\x62\x61reun\"\x90\x01\n\x07\x44ictSet\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.bareun.DictSet.ItemsEntry\x12\x1e\n\x04type\x18\x02 \x01(\x0e\x32\x10.bareun.DictType\x12\x0c\n\x04name\x18\n \x01(\t\x1a,\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01*B\n\x08\x44ictType\x12\x0f\n\x0bTOKEN_INDEX\x10\x00\x12\r\n\tWORD_LIST\x10\x01\x12\x16\n\x12WORD_LIST_COMPOUND\x10\x02\x42\x43\n\x10\x61i.bareun.protosB\x15\x44ictionaryCommonProtoP\x01Z\x16\x62\x61reun.ai/proto/bareunb\x06proto3')

_DICTTYPE = DESCRIPTOR.enum_types_by_name['DictType']
DictType = enum_type_wrapper.EnumTypeWrapper(_DICTTYPE)
TOKEN_INDEX = 0
WORD_LIST = 1
WORD_LIST_COMPOUND = 2


_DICTSET = DESCRIPTOR.message_types_by_name['DictSet']
_DICTSET_ITEMSENTRY = _DICTSET.nested_types_by_name['ItemsEntry']
DictSet = _reflection.GeneratedProtocolMessageType('DictSet', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DICTSET_ITEMSENTRY,
    '__module__' : 'bareun.dict_common_pb2'
    # @@protoc_insertion_point(class_scope:bareun.DictSet.ItemsEntry)
    })
  ,
  'DESCRIPTOR' : _DICTSET,
  '__module__' : 'bareun.dict_common_pb2'
  # @@protoc_insertion_point(class_scope:bareun.DictSet)
  })
_sym_db.RegisterMessage(DictSet)
_sym_db.RegisterMessage(DictSet.ItemsEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020ai.bareun.protosB\025DictionaryCommonProtoP\001Z\026bareun.ai/proto/bareun'
  _DICTSET_ITEMSENTRY._options = None
  _DICTSET_ITEMSENTRY._serialized_options = b'8\001'
  _DICTTYPE._serialized_start=183
  _DICTTYPE._serialized_end=249
  _DICTSET._serialized_start=37
  _DICTSET._serialized_end=181
  _DICTSET_ITEMSENTRY._serialized_start=137
  _DICTSET_ITEMSENTRY._serialized_end=181
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bareun import revision_service_pb2 as bareun_dot_revision__service__pb2


class RevisionServiceStub(object):
    """다양한 목적에 맞는 문장 교정 서비스
    이 서비스는 다른 과금 체계를 가지므로 다양하게 재구성한다.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CorrectError = channel.unary_unary(
                '/bareun.RevisionService/CorrectError',
                request_serializer=bareun_dot_revision__service__pb2.CorrectErrorRequest.SerializeToString,
                response_deserializer=bareun_dot_revision__service__pb2.CorrectErrorResponse.FromString,
                )


class RevisionServiceServicer(object):
    """다양한 목적에 맞는 문장 교정 서비스
    이 서비스는 다른 과금 체계를 가지므로 다양하게 재구성한다.
    """

    def CorrectError(self, request, context):
        """맞춤법 교정을 수행한다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RevisionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CorrectError': grpc.unary_unary_rpc_method_handler(
                    servicer.CorrectError,
                    request_deserializer=bareun_dot_revision__service__pb2.CorrectErrorRequest.FromString,
                    response_serializer=bareun_dot_revision__service__pb2.CorrectErrorResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bareun.RevisionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RevisionService(object):
    """다양한 목적에 맞는 문장 교정 서비스
    이 서비스는 다른 과금 체계를 가지므로 다양하게 재구성한다.
    """

    @staticmethod
    def CorrectError(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.RevisionService/CorrectError',
            bareun_dot_revision__service__pb2.CorrectErrorRequest.SerializeToString,
            bareun_dot_revision__service__pb2.CorrectErrorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
